@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2023 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,8 @@
 Handler for importer batches
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import logging
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 
@@ -106,7 +103,7 @@ class ImporterBatchHandler(BatchHandler):
                         host_data[field] = getattr(row, col.name)
                 key = importer.get_key(host_data)
                 local_object = importer.get_local_object(key)
-                text = six.text_type(local_object)
+                text = str(local_object)
                 importer.delete_object(local_object)
                 log.debug("deleted %s %s: %s", importer.model_name, key, text)
 
