@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,16 +24,13 @@
 Handler for inventory batches
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import decimal
 import logging
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 
-from rattail.db import api, model
+from rattail.db import model
 from rattail.gpc import GPC
 from rattail.batch import BatchHandler
 
@@ -276,7 +273,11 @@ class InventoryBatchHandler(BatchHandler):
             product, embedded_price = type2
         else:
             product = self.locate_product_for_entry(session, entry,
-                                                    lookup_by_code=True)
+                                                    lookup_fields=[
+                                                        'uuid',
+                                                        '_product_key_',
+                                                        'alt_code',
+                                                    ])
 
         if product:
             if product.is_pack_item():
@@ -349,7 +350,7 @@ class InventoryBatchHandler(BatchHandler):
         if not product:
             if row.upc:
                 session = orm.object_session(row)
-                product = api.get_product_by_upc(session, row.upc)
+                product = self.locate_product_for_entry(session, row.upc)
             if not product:
                 row.status_code = row.STATUS_PRODUCT_NOT_FOUND
                 return
@@ -358,7 +359,7 @@ class InventoryBatchHandler(BatchHandler):
         row.product = product
         row.upc = product.upc
         row.item_id = product.item_id
-        row.brand_name = six.text_type(product.brand or '')
+        row.brand_name = str(product.brand or '')
         row.description = product.description
         row.size = product.size
         row.status_code = row.STATUS_OK
