@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,24 +24,15 @@
 Handler for label batches
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import csv
 import decimal
 import logging
 
-import six
 import json
-import sqlalchemy as sa
-from sqlalchemy import orm
 
-from rattail import enum
-from rattail.db import model, api
-from rattail.gpc import GPC
+from rattail.db.model import LabelBatch
 from rattail.batch import BatchHandler
 from rattail.csvutil import UnicodeDictReader
-from rattail.time import make_utc
-from rattail.config import parse_bool
 
 
 log = logging.getLogger(__name__)
@@ -51,10 +42,14 @@ class LabelBatchHandler(BatchHandler):
     """
     Handler for Print Labels batches.
     """
-    batch_model_class = model.LabelBatch
+    batch_model_class = LabelBatch
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.products_handler = self.app.get_products_handler()
 
     def setup(self, batch, progress=None):
-        self.now = make_utc()
+        self.now = self.app.make_utc()
 
     setup_populate = setup
     setup_refresh = setup
@@ -64,12 +59,12 @@ class LabelBatchHandler(BatchHandler):
         """
         Make a new batch, with initial rows if applicable.
         """
-        self.skip_first_line = parse_bool(kwargs.pop('skip_first_line', False))
+        self.skip_first_line = self.config.parse_bool(kwargs.pop('skip_first_line', False))
         self.calc_check_digit = kwargs.pop('calc_check_digit', False)
         if self.calc_check_digit != 'upc':
-            self.calc_check_digit = parse_bool(self.calc_check_digit)
-        file_has_options = parse_bool(kwargs.pop('file_has_options', False))
-        batch = super(LabelBatchHandler, self).make_batch(session, progress, **kwargs)
+            self.calc_check_digit = self.config.parse_bool(self.calc_check_digit)
+        file_has_options = self.config.parse_bool(kwargs.pop('file_has_options', False))
+        batch = super().make_batch(session, progress, **kwargs)
         batch.file_has_options = file_has_options
         return batch
 
@@ -86,7 +81,8 @@ class LabelBatchHandler(BatchHandler):
         """
         Pre-fill batch with row data from handheld batch, etc.
         """
-        session = orm.object_session(batch)
+        model = self.model
+        session = self.app.get_session(batch)
         if batch.label_profile:
             self.label_profile = batch.label_profile
         else:
@@ -100,7 +96,7 @@ class LabelBatchHandler(BatchHandler):
         label_code = self.label_profile.code if self.label_profile else None
 
         def append(item, i):
-            row = model.LabelBatchRow()
+            row = self.make_row()
             row.label_code = label_code
             row.label_profile = self.label_profile
             with session.no_autoflush:
@@ -141,12 +137,12 @@ class LabelBatchHandler(BatchHandler):
         """
         Populate label batch from product batch.
         """
-        session = orm.object_session(batch)
+        session = self.app.get_session(batch)
         product_batch = batch.product_batch
         label_code = self.label_profile.code if self.label_profile else None
 
         def add(prow, i):
-            row = model.LabelBatchRow()
+            row = self.make_row()
             row.label_code = label_code
             row.label_profile = self.label_profile
             row.label_quantity = 1
@@ -163,6 +159,7 @@ class LabelBatchHandler(BatchHandler):
         """
         Set various batch options, if any are present within the data file.
         """
+        model = self.model
         path = batch.filepath(self.config)
         with open(path, 'rt') as f:
             options = json.loads(f.readline())
@@ -175,7 +172,7 @@ class LabelBatchHandler(BatchHandler):
         if 'label_code' in options:
             batch.label_code = options['label_code']
             if batch.label_code:
-                session = orm.object_session(batch)
+                session = self.app.get_session(batch)
                 batch.label_profile = session.query(model.LabelProfile)\
                                              .filter(model.LabelProfile.code == batch.label_code)\
                                              .one()
@@ -205,17 +202,17 @@ class LabelBatchHandler(BatchHandler):
                 data = list(reader)
 
         products = []
-        session = orm.object_session(batch)
+        session = self.app.get_session(batch)
 
         def append(entry, i):
             upc = entry['upc'].strip()
             if upc:
                 try:
-                    upc = GPC(upc, calc_check_digit=self.calc_check_digit)
+                    upc = self.app.make_gpc(upc, calc_check_digit=self.calc_check_digit)
                 except ValueError:
                     pass
                 else:
-                    product = api.get_product_by_upc(session, upc)
+                    product = self.products_handler.locate_product_for_gpc(session, upc)
                     if product:
                         if batch.static_prices and entry['regular_price']:
                             product._batch_price = decimal.Decimal(entry['regular_price'])
@@ -228,6 +225,7 @@ class LabelBatchHandler(BatchHandler):
         return products
 
     def get_label_profile(self, session):
+        model = self.model
         code = self.config.get('rattail.batch', 'labels.default_code')
         if code:
             return session.query(model.LabelProfile)\
@@ -244,11 +242,11 @@ class LabelBatchHandler(BatchHandler):
         for it, according to what we find in the database.
         """
         if not row.product:
-            session = orm.object_session(row)
+            session = self.app.get_session(row)
             if row.item_entry:
                 row.product = self.locate_product_for_entry(session, row.item_entry)
             if not row.product and row.upc:
-                row.product = api.get_product_by_upc(session, row.upc)
+                row.product = self.products_handler.locate_product_for_gpc(session, row.upc)
             if not row.product:
                 row.status_code = row.STATUS_PRODUCT_NOT_FOUND
                 return
@@ -268,8 +266,8 @@ class LabelBatchHandler(BatchHandler):
 
             sale_price = product.sale_price
             if sale_price:
-                now = getattr(self, 'now', None) or make_utc()
-                if (sale_price.type == enum.PRICE_TYPE_SALE and
+                now = getattr(self, 'now', None) or self.app.make_utc()
+                if (sale_price.type == self.enum.PRICE_TYPE_SALE and
                     sale_price.starts and sale_price.starts <= now and
                     sale_price.ends and sale_price.ends >= now):
                     pass            # this is what we want
@@ -388,6 +386,6 @@ class LabelBatchHandler(BatchHandler):
                            message="Organizing labels by type")
 
         # okay now print for real
-        for profile in six.itervalues(profiles):
+        for profile in profiles.values():
             printer = label_handler.get_printer(profile)
             printer.print_labels(profile.labels, progress=progress)
