@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,14 +24,11 @@
 Handler for pricing batches
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import decimal
 
-import six
 from sqlalchemy import orm
 
-from rattail.db import model, api
+from rattail.db.model import PricingBatch
 from rattail.gpc import GPC
 from rattail.batch import BatchHandler
 from rattail.excel import ExcelReaderXLSX
@@ -41,7 +38,7 @@ class PricingBatchHandler(BatchHandler):
     """
     Handler for pricing batches.
     """
-    batch_model_class = model.PricingBatch
+    batch_model_class = PricingBatch
 
     # cached decimal object used for rounding percentages, below
     percent_decimal = decimal.Decimal('.001')
@@ -112,14 +109,14 @@ class PricingBatchHandler(BatchHandler):
         session = orm.object_session(batch)
 
         def append(excel, i):
-            row = model.PricingBatchRow()
+            row = self.make_row()
 
             if 'upc' in excel:
                 item_entry = excel['upc']
             else:
                 item_entry = excel.get('UPC')
             if isinstance(item_entry, float):
-                item_entry = six.text_type(int(item_entry))
+                item_entry = str(int(item_entry))
             row.item_entry = item_entry
 
             row.product = self.locate_product_for_entry(session, row.item_entry)
@@ -143,7 +140,7 @@ class PricingBatchHandler(BatchHandler):
         product_batch = batch.product_batch
 
         def add(prow, i):
-            row = model.PricingBatchRow()
+            row = self.make_row()
             row.item_entry = prow.item_entry
             with session.no_autoflush:
                 row.product = prow.product
@@ -171,6 +168,7 @@ class PricingBatchHandler(BatchHandler):
         Find and return a list of all products whose "regular price" is greater
         than "suggested price" (SRP).
         """
+        model = self.model
         query = session.query(model.Product)\
                        .options(orm.joinedload(model.Product.regular_price))\
                        .options(orm.joinedload(model.Product.suggested_price))
@@ -202,7 +200,7 @@ class PricingBatchHandler(BatchHandler):
 
         row.item_id = product.item_id
         row.upc = product.upc
-        row.brand_name = six.text_type(product.brand or '')
+        row.brand_name = str(product.brand or '')
         row.description = product.description
         row.size = product.size
 
