@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,14 +24,10 @@
 Email Bouncer Configuration
 """
 
-from __future__ import unicode_literals
-
-from rattail.config import parse_list
-from rattail.util import load_object
 from rattail.exceptions import ConfigurationError
 
 
-class Profile(object):
+class Profile:
     """
     Simple class to hold configuration for an email bouncer "profile".  Each
     profile determines how to connect to an IMAP folder, which handler to
@@ -78,6 +74,7 @@ class Profile(object):
     def __init__(self, config, key):
         self.config = config
         self.key = key
+        self.app = self.config.get_app()
 
         self.imap_server = self._config_string('imap.server')
         self.imap_username = self._config_string('imap.username')
@@ -90,7 +87,7 @@ class Profile(object):
         self.workdir = self._config_string('workdir')
 
         self.handler_spec = self._config_string('handler') or 'rattail.bouncer:BounceHandler'
-        self.handler = load_object(self.handler_spec)(config, key)
+        self.handler = self.app.load_object(self.handler_spec)(config, key)
 
     def _config_string(self, option):
         return self.config.get('rattail.bouncer', '{0}.{1}'.format(self.key, option))
@@ -116,7 +113,7 @@ def get_profile_keys(config):
     """
     keys = config.get('rattail.bouncer', 'watch')
     if keys:
-        return parse_list(keys)
+        return config.parse_list(keys)
 
 
 def load_profiles(config):
