@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,16 +24,11 @@
 Vendor catalog parser for Equal Exchange
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import re
 import decimal
 
-import six
 import xlrd
 
-from rattail.db import model
-from rattail.gpc import GPC
 from rattail.vendors.catalogs import CatalogParser
 
 
@@ -62,7 +57,7 @@ class EqualExchangeCatalogParser(CatalogParser):
         unit_price_pattern = re.compile(r'^\$(\d+\.\d\d)/lb$')
 
         for r in range(sheet.nrows):
-            row = model.VendorCatalogBatchRow()
+            row = self.make_row()
             row.brand_name = "Equal Exchange"
             row.department_name = department_name
 
@@ -74,13 +69,13 @@ class EqualExchangeCatalogParser(CatalogParser):
             item_code = sheet.cell_value(r, 1)
             if not isinstance(item_code, (int, float)):
                 continue
-            row.vendor_code = six.text_type(int(item_code))
+            row.vendor_code = str(int(item_code))
 
             # column C (UNIT UPC)
             # note that this must be present, or else we're not interested
             unit_upc = sheet.cell_value(r, 2)
             if isinstance(unit_upc, float):
-                unit_upc = six.text_type(int(unit_upc))
+                unit_upc = str(int(unit_upc))
             unit_upc = unit_upc.replace(' ', '')
             if not unit_upc:
                 continue
@@ -89,12 +84,12 @@ class EqualExchangeCatalogParser(CatalogParser):
             if unit_upc != 'NA':
                 assert len(unit_upc) == 12
                 row.item_entry = unit_upc
-                row.upc = GPC(unit_upc, calc_check_digit=False)
+                row.upc = self.app.make_gpc(unit_upc, calc_check_digit=False)
 
             # column E (UNIT PRICE)
             unit_price = sheet.cell_value(r, 4)
             if isinstance(unit_price, float):
-                row.unit_cost = decimal.Decimal(six.text_type(unit_price))\
+                row.unit_cost = decimal.Decimal(str(unit_price))\
                                        .quantize(decimal.Decimal('0.12345'))
             else:
                 match = unit_price_pattern.match(unit_price)
@@ -108,7 +103,7 @@ class EqualExchangeCatalogParser(CatalogParser):
 
             # column G (PRICE/CASE)
             price_per_case = sheet.cell_value(r, 6)
-            row.case_cost = decimal.Decimal(six.text_type(price_per_case))\
+            row.case_cost = decimal.Decimal(str(price_per_case))\
                                    .quantize(decimal.Decimal('0.12345'))
 
             yield row
