@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,14 +24,10 @@
 "Generic" Catalog Parser
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 import decimal
 import logging
 
-import six
-
 from rattail.vendors.catalogs import CatalogParser
 from rattail.excel import ExcelReaderXLSX
 
@@ -58,7 +54,7 @@ class GenericCatalogParser(CatalogParser):
 
             # upc (required)
             upc = xlrow['UPC']
-            if not upc or not six.text_type(upc).strip():
+            if not upc or not str(upc).strip():
                 continue        # skip lines with no UPC value
             row.item_entry = upc
             row.upc = self.app.make_gpc(upc)
@@ -83,7 +79,7 @@ class GenericCatalogParser(CatalogParser):
             if 'Vendor Code' in xlrow:
                 vendor_code = xlrow['Vendor Code']
                 if vendor_code is not None:
-                    row.vendor_code = six.text_type(vendor_code)
+                    row.vendor_code = str(vendor_code)
 
             if 'Brand' in xlrow:
                 row.brand_name = xlrow['Brand']
