@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,17 +24,12 @@
 Vendor catalog parser for United Natural Foods (UNFI)
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import re
 import datetime
 import decimal
 
-import six
 import xlrd
 
-from rattail.db import model
-from rattail.gpc import GPC
 from rattail.vendors.catalogs import CatalogParser
 from rattail.csvutil import UnicodeDictReader
 
@@ -74,20 +69,20 @@ class UNFICatalogParser(CatalogParser):
             # Warn if UPC is not valid.
             upc = sheet.cell_value(r, 1)
             if self.upc_pattern.match(upc):
-                upc = GPC(upc.replace('-', ''))
+                upc = self.app.make_gpc(upc.replace('-', ''))
             else:
                 log.warning("invalid upc at row {0}: {1}".format(r + 1, upc))
                 upc = None
 
-            row = model.VendorCatalogBatchRow()
+            row = self.make_row()
             row.upc = upc
             row.vendor_code = code.replace('-', '')
             row.brand_name = sheet.cell_value(r, 2)
             row.description = sheet.cell_value(r, 3)
             row.size = sheet.cell_value(r, 5)
             row.case_size = int(sheet.cell_value(r, 4))
-            row.case_cost = decimal.Decimal(six.text_type(sheet.cell_value(r, 8)))
-            row.unit_cost = decimal.Decimal(six.text_type(sheet.cell_value(r, 9)))
+            row.case_cost = decimal.Decimal(str(sheet.cell_value(r, 8)))
+            row.unit_cost = decimal.Decimal(str(sheet.cell_value(r, 9)))
             yield row
 
 
@@ -110,20 +105,20 @@ class UNFICatalogParser2(UNFICatalogParser):
             # Warn if UPC is not valid.
             upc = sheet.cell_value(r, 1)
             if self.upc_pattern.match(upc):
-                upc = GPC(upc.replace('-', ''))
+                upc = self.app.make_gpc(upc.replace('-', ''))
             else:
                 log.warning("invalid upc at row {0}: {1}".format(r + 1, upc))
                 upc = None
 
-            row = model.VendorCatalogBatchRow()
+            row = self.make_row()
             row.upc = upc
             row.vendor_code = code.replace('-', '')
             row.brand_name = sheet.cell_value(r, 2)
             row.description = sheet.cell_value(r, 4)
             row.size = sheet.cell_value(r, 7)
             row.case_size = int(sheet.cell_value(r, 6))
-            row.case_cost = decimal.Decimal(six.text_type(sheet.cell_value(r, 10)))
-            row.unit_cost = decimal.Decimal(six.text_type(sheet.cell_value(r, 11)))
+            row.case_cost = decimal.Decimal(str(sheet.cell_value(r, 10)))
+            row.unit_cost = decimal.Decimal(str(sheet.cell_value(r, 11)))
             yield row
 
 
@@ -136,17 +131,10 @@ class UNFITabSeparatedCatalogParser(CatalogParser):
     vendor_key = 'unfi'
 
     def parse_rows(self, csv_path, progress=None):
-        if six.PY3:
-            csv_file = open(csv_path, 'rt', encoding='latin_1')
-            # nb. skip first "message" line
-            next(csv_file)
-            reader = UnicodeDictReader(csv_file, dialect='excel-tab')
-        else: # PY2
-            csv_file = open(csv_path, 'rb')
-            # nb. skip first "message" line
-            next(csv_file)
-            reader = UnicodeDictReader(csv_file, encoding='latin_1',
-                                       dialect='excel-tab')
+        csv_file = open(csv_path, 'rt', encoding='latin_1')
+        # nb. skip first "message" line
+        next(csv_file)
+        reader = UnicodeDictReader(csv_file, dialect='excel-tab')
 
         for csvrow in reader:
             row = self.make_row()
