@@ -4,10 +4,6 @@
 Views for ${model_title} batches
 """
 
-from __future__ import unicode_literals, absolute_import
-
-import six
-
 from rattail.db import model
 
 from webhelpers2.html import tags
@@ -51,7 +47,7 @@ class ${model_name}View(FileBatchMasterView):
     ]
 
     def get_instance_title(self, batch):
-        return six.text_type(batch.vendor)
+        return str(batch.vendor)
 
     def configure_grid(self, g):
         super(${model_name}View, self).configure_grid(g)
