@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 DataSync for Linux
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import sys
 import time
 import logging
@@ -263,7 +261,7 @@ def record_or_process_changes(config, watcher, changes):
        ``True`` if no error.
     """
     app = config.get_app()
-    model = config.get_model()
+    model = app.model
 
     # if watcher consumes itself, then it will process its own
     # changes.  note that there are no assumptions made about the
@@ -424,7 +422,7 @@ def consume_current_changes(config, consumer):
     :returns: ``True`` if all goes well, ``False`` if error.
     """
     app = config.get_app()
-    model = config.get_model()
+    model = app.model
 
     try:
         session = app.make_session()
@@ -542,7 +540,7 @@ def consume_changes_from(config, session, consumer, obtained):
     :returns: ``True`` if all goes well, ``False`` if error.
     """
     app = config.get_app()
-    model = config.get_model()
+    model = app.model
 
     # we only want changes "obtained" at the given time.  however, at least
     # until all code has been refactored, we must take two possibilities into
