@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2023 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,11 +26,8 @@ DataSync for Rattail
 
 import logging
 
-from sqlalchemy import orm
-
 from rattail.db.util import make_topo_sortkey
 from rattail.datasync import DataSyncWatcher, DataSyncConsumer, DataSyncImportConsumer
-from rattail.config import parse_list
 
 
 log = logging.getLogger(__name__)
@@ -43,9 +40,9 @@ class RattailWatcher(DataSyncWatcher):
     prunes_changes = True
 
     def __init__(self, *args, **kwargs):
-        super(RattailWatcher, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.engine = self.config.rattail_engines[self.dbkey]
-        self.topo_sortkey = make_topo_sortkey(self.config.get_model())
+        self.topo_sortkey = make_topo_sortkey(self.app.model)
 
     def get_changes(self, lastrun):
         """
@@ -178,7 +175,7 @@ class RattailConsumer(DataSyncConsumer):
     ignore_models = None
 
     def __init__(self, *args, **kwargs):
-        super(RattailConsumer, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.engine = self.config.rattail_engines[self.dbkey]
         self.model = self.get_data_model()
         self.topo_sortkey = make_topo_sortkey(self.model)
@@ -189,7 +186,7 @@ class RattailConsumer(DataSyncConsumer):
         Subclasses may override this if they have extended the schema.
         Defaults to ``rattail.db.model``.
         """
-        return self.config.get_model()
+        return self.app.model
 
     def process_changes(self, host_session, changes):
         """
@@ -389,7 +386,7 @@ class FromRattailToRattailBase(DataSyncImportConsumer):
     """
 
     def setup(self):
-        super(FromRattailToRattailBase, self).setup()
+        super().setup()
         self.topo_sortkey = make_topo_sortkey(self.model)
         self.handle_price_xref = self.get_handle_price_xref()
 
@@ -403,7 +400,7 @@ class FromRattailToRattailBase(DataSyncImportConsumer):
             default=False)
 
     def get_importers(self):
-        importers = super(FromRattailToRattailBase, self).get_importers()
+        importers = super().get_importers()
 
         # add the GlobalRole importer, in place of Role, unless latter
         # is already present.
@@ -431,9 +428,9 @@ class FromRattailToRattailExportConsumer(FromRattailToRattailBase):
     handler_spec = None
 
     def __init__(self, *args, **kwargs):
-        super(FromRattailToRattailExportConsumer, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.target_engine = self.config.rattail_engines[self.dbkey]
-        self.model = self.config.get_model()
+        self.model = self.app.model
 
     def make_target_session(self):
         return self.app.make_session(bind=self.target_engine)
@@ -473,10 +470,10 @@ class FromRattailToRattailImportConsumer(FromRattailToRattailBase):
     handler_spec = None
 
     def __init__(self, *args, **kwargs):
-        super(FromRattailToRattailImportConsumer, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.host_engine = self.config.rattail_engines[self.watcher.dbkey]
         self.local_engine = self.config.rattail_engines[self.dbkey]
-        self.model = self.config.get_model()
+        self.model = self.app.model
 
     def process_changes(self, session, changes):
         self.host_session = self.app.make_session(bind=self.host_engine)
@@ -509,5 +506,4 @@ class FromRattailToRattailImportConsumer(FromRattailToRattailBase):
     def get_host_object(self, session, change):
         # we use base logic to get the object, but must substitute the
         # session to ensure we read from actual host and not local
-        return super(FromRattailToRattailImportConsumer, self).get_host_object(
-            self.host_session, change)
+        return super().get_host_object(self.host_session, change)
