@@ -137,7 +137,7 @@ def next_batch_id(session):
 
 def purge_datasync_settings(config, session):
     app = config.get_app()
-    model = config.get_model()
+    model = app.model
 
     to_delete = session.query(model.Setting)\
                        .filter(sa.or_(
@@ -145,13 +145,15 @@ def purge_datasync_settings(config, session):
                            model.Setting.name == 'rattail.datasync.supervisor_process_name',
                            model.Setting.name == 'rattail.datasync.use_profile_settings',
                            model.Setting.name == 'tailbone.datasync.restart',
-                           model.Setting.name.like('rattail.datasync.%.watcher'),
+                           model.Setting.name.like('rattail.datasync.%.watcher'), # DEPRECATED
+                           model.Setting.name.like('rattail.datasync.%.watcher.spec'),
                            model.Setting.name.like('rattail.datasync.%.watcher.db'),
                            model.Setting.name.like('rattail.datasync.%.watcher.delay'),
                            model.Setting.name.like('rattail.datasync.%.watcher.retry_attempts'),
                            model.Setting.name.like('rattail.datasync.%.watcher.retry_delay'),
                            model.Setting.name.like('rattail.datasync.%.watcher.kwarg.%'),
-                           model.Setting.name.like('rattail.datasync.%.consumers'),
+                           model.Setting.name.like('rattail.datasync.%.consumers'), # DEPRECATED
+                           model.Setting.name.like('rattail.datasync.%.consumers.list'),
                            model.Setting.name.like('rattail.datasync.%.consumers.runas'),
                            model.Setting.name.like('rattail.datasync.%.consumer.%')))\
                        .all()
