@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2023 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -28,10 +28,8 @@ import datetime
 
 import sqlalchemy as sa
 
-from rattail.time import make_utc, localtime
 
-
-class DataSyncWatcher(object):
+class DataSyncWatcher:
     """
     Base class for all DataSync watchers.
     """
@@ -56,8 +54,8 @@ class DataSyncWatcher(object):
         self.key = key
         self.dbkey = dbkey
         self.delay = 1 # seconds
-        self.model = self.config.get_model()
         self.app = self.config.get_app()
+        self.model = self.app.model
 
     def setup(self):
         """
@@ -71,11 +69,11 @@ class DataSyncWatcher(object):
         "other" server.
         """
         # get current time according to "other" server, and convert to UTC
-        before = make_utc()
+        before = self.app.make_utc()
         other_now = session.execute(sa.text('select current_timestamp'))\
                            .fetchone()[0]
-        after = make_utc()
-        other_now = make_utc(localtime(self.config, other_now))
+        after = self.app.make_utc()
+        other_now = self.app.make_utc(self.app.localtime(other_now))
 
         # get current time according to local server (i.e. Rattail), in UTC
         local_now = after
@@ -92,7 +90,7 @@ class DataSyncWatcher(object):
         drift += datetime.timedelta(seconds=1)
 
         # convert lastrun time to local timezone, for "other" queries
-        lastrun = localtime(self.config, lastrun, tzinfo=False)
+        lastrun = self.app.localtime(lastrun, tzinfo=False)
 
         # and finally, apply the drift
         return lastrun - drift
