@@ -1,15 +1,13 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 """
 Alembic Environment Script
 """
 
-from __future__ import unicode_literals, absolute_import
-
 from alembic import context
-from sqlalchemy.orm import configure_mappers
+from sqlalchemy import orm
 
 from rattail.config import make_config
-from rattail.db.continuum import configure_versioning
+from rattail.db.config import configure_versioning
 
 
 # this is the Alembic Config object, which provides
@@ -17,12 +15,15 @@ from rattail.db.continuum import configure_versioning
 alembic_config = context.config
 
 # Use same config file for Rattail, as we are for Alembic.
-rattail_config = make_config(alembic_config.config_file_name, versioning=False)
+rattail_config = make_config(alembic_config.config_file_name,
+                             usedb=False,
+                             versioning=False)
 
 # Configure Continuum...this is trickier than I'd like.
 configure_versioning(rattail_config, force=True)
-model = rattail_config.get_model()
-configure_mappers()
+app = rattail_config.get_app()
+model = app.model
+orm.configure_mappers()
 
 # add your model's MetaData object here
 # for 'autogenerate' support
