@@ -27,7 +27,8 @@ def upgrade():
     op.add_column('product', sa.Column('discontinued', sa.Boolean(), nullable=True))
     product = sa.sql.table('product', sa.sql.column('discontinued'))
     op.execute(product.update().values({'discontinued': False}))
-    op.alter_column('product', 'discontinued', nullable=False)
+    op.alter_column('product', 'discontinued', nullable=False,
+                    existing_type=sa.Boolean())
 
 
 def downgrade():
