@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Settings API
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import warnings
 
 from rattail.db import Session, model
@@ -43,7 +41,7 @@ def get_setting(session, name):
     if session is None:
         session = Session()
         local_session = True
-    setting = session.query(model.Setting).get(name)
+    setting = session.get(model.Setting, name)
     value = None if setting is None else setting.value
     if local_session:
         session.close()
@@ -62,7 +60,7 @@ def save_setting(session, name, value):
     if session is None:
         session = Session()
         local_session = True
-    setting = session.query(model.Setting).get(name)
+    setting = session.get(model.Setting, name)
     if not setting:
         setting = model.Setting(name=name)
         session.add(setting)
