@@ -24,27 +24,19 @@
 API for Store Models
 """
 
+import warnings
+
 from sqlalchemy.orm.exc import NoResultFound
 
 from rattail.db import model
 
 
-# TODO: need to refactor this into the AppHandler, or..?
 def get_store(session, key):
-    """
-    Locate and return a store for the given key, if possible.
+    """ DEPRECATED """
+    warnings.warn("db.api.get_store() function is deprecated; "
+                  "please use OrgHandler.get_store() method instead",
+                  DeprecationWarning, stacklevel=2)
 
-    First the key is assumed to be a ``Store.id`` value.  If no matches are
-    found, then it looks for a special setting in the database.  If one is
-    found, ``get_store()`` is called again with its value.
-
-    :param session: Active database session.
-
-    :param key: Value to use when searching for the store.
-
-    :returns: The :class:`rattail.db.model.Store` instance if found; otherwise
-      ``None``.
-    """
     # Store.uuid match?
     store = session.get(model.Store, key)
     if store:
