@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,16 +24,13 @@
 Cache Helpers
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import logging
+from collections import OrderedDict
 
-import six
 from sqlalchemy.orm import joinedload
 
 from rattail.core import Object
 from rattail.db import model
-from rattail.util import OrderedDict
 
 
 log = logging.getLogger(__name__)
@@ -121,7 +118,7 @@ class ModelCacher(object):
     def get_key(self, instance, normalized):
         if callable(self.key):
             return self.key(instance, normalized)
-        if isinstance(self.key, six.string_types):
+        if isinstance(self.key, str):
             return getattr(instance, self.key)
         return tuple(getattr(instance, k) for k in self.key)
 
