@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2023 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -36,9 +36,7 @@ try:
 except ImportError:
     listen = None # old SQLAlchemy; will have to work around that, below
 
-from rattail.db import model
-from rattail.core import get_uuid
-from rattail.util import load_object
+from rattail.db.model import Setting, Change, DataSyncChange
 
 try:
     from rattail.db.continuum import versioning_manager
@@ -62,9 +60,10 @@ def record_changes(session, recorder=None, config=None):
         recorder = recorder(config)
     elif recorder is None:
         if config:
+            app = config.get_app()
             spec = config.get('rattail.db', 'changes.recorder', usedb=False)
             if spec:
-                recorder = load_object(spec)(config)
+                recorder = app.load_object(spec)(config)
         if not recorder:
             recorder = ChangeRecorder(config)
     else:
@@ -83,7 +82,7 @@ def record_changes(session, recorder=None, config=None):
     session.rattail_change_recorder = recorder
 
 
-class ChangeRecorder(object):
+class ChangeRecorder:
     """
     Listener for session ``before_flush`` events.
 
@@ -92,9 +91,9 @@ class ChangeRecorder(object):
     data propagation.
     """
     ignored_classes = (
-        model.Setting,
-        model.Change,
-        model.DataSyncChange,
+        Setting,
+        Change,
+        DataSyncChange,
     )
 
     # once upon a time we supposedly needed to specify `passive=True` when
@@ -108,7 +107,8 @@ class ChangeRecorder(object):
     def __init__(self, config):
         self.config = config
         if self.config:
-            self.model = config.get_model()
+            self.app = self.config.get_app()
+            self.model = self.app.model
 
     def __call__(self, session, flush_context, instances):
         """
@@ -141,6 +141,9 @@ class ChangeRecorder(object):
         """
         Return ``True`` if changes for the given object should be ignored.
         """
+        app = self.config.get_app()
+        model = self.app.model
+
         # ignore certain classes per declaration
         if isinstance(obj, self.ignored_classes):
             return True
@@ -172,6 +175,8 @@ class ChangeRecorder(object):
         """
         Record changes as appropriate, for the given 'deleted' object.
         """
+        model = self.app.model
+
         # TODO: should perhaps find a "cleaner" way to handle these..?
 
         # mark Person as dirty, when contact info is removed
@@ -228,6 +233,8 @@ class ChangeRecorder(object):
         :returns: ``True`` if a change was recorded, or ``False`` if it was
            ignored.
         """
+        model = self.app.model
+
         # TODO: this check is now redundant due to `ignore_object()`
         # No need to record changes for changes.
         if isinstance(instance, (model.Change, model.DataSyncChange)):
@@ -261,6 +268,7 @@ class ChangeRecorder(object):
         """
         Record a change, by creating a new change record in the session.
         """
+        model = self.app.model
         session.add(model.Change(**kwargs))
         if not quiet:
             log.debug("recorded {} for {} with key: {}".format(
@@ -288,7 +296,7 @@ class ChangeRecorder(object):
 
         mapper = object_mapper(instance)
         if not mapper.columns['uuid'].foreign_keys:
-            instance.uuid = get_uuid()
+            instance.uuid = self.app.make_uuid()
             return
 
         for prop in mapper.iterate_properties:
@@ -302,7 +310,7 @@ class ChangeRecorder(object):
                     instance.uuid = foreign_instance.uuid
                     return
 
-        instance.uuid = get_uuid()
+        instance.uuid = self.app.make_uuid()
         log.error("unexpected scenario; generated new UUID for instance: {0}".format(repr(instance)))
 
 
