@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,126 +24,40 @@
 Database Configuration
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import logging
+import warnings
+
+from wuttjamaican.util import parse_bool
+from wuttjamaican.db.conf import make_engine_from_config as wutta_make_engine_from_config
 
-from rattail.util import load_object, OrderedDict
 from rattail.exceptions import SQLAlchemyNotInstalled
-from rattail.config import parse_list, parse_bool
 
 
 log = logging.getLogger(__name__)
 
 
-def engine_from_config(configuration, prefix='sqlalchemy.', **kwargs):
-    """
-    Custom version of the identically-named SQLAlchemy function.
-
-    The purpose of the customization is to allow the ``poolclass`` parameter to
-    be specified within the configuration.  If this option is present in the
-    configuration dictionary, it will be coerced to the Python class it
-    references and passed as a keyword argument to the "upstream" function.
-
-    An example of the configuration leveraging this feature:
-
-    .. code-block:: ini
-
-       [rattail.db]
-       sqlalchemy.url = sqlite:///tmp/rattail.sqlite
-       sqlalchemy.poolclass = sqlalchemy.pool:NullPool
-    """
-    try:
-        from sqlalchemy import engine_from_config
-    except ImportError as error:
-        raise SQLAlchemyNotInstalled(error)
-
-    config = dict(configuration)
-
-    # Convert 'poolclass' arg to actual class.
-    key = '{}poolclass'.format(prefix)
-    if key in config:
-        kwargs.setdefault('poolclass', load_object(config[key]))
-        del config[key]
-
-    # convert 'pool_pre_ping' arg to boolean
-    key = '{}pool_pre_ping'.format(prefix)
-    if key in config:
-        kwargs.setdefault('pool_pre_ping', parse_bool(config[key]))
-        del config[key]
-
-    # Store 'record_changes' flag as attribute on engine.
-    record_changes = False
-    key = '{}record_changes'.format(prefix)
-    if key in config:
-        value = config.pop(key)
-        record_changes = parse_bool(value)
-
-    # stash flag for logging db pool status
-    log_pool_status = False
-    key = '{}log_pool_status'.format(prefix)
-    if key in config:
-        value = config.pop(key)
-        log_pool_status = parse_bool(value)
-
-    engine = engine_from_config(config, prefix, **kwargs)
-
-    if record_changes:
-        engine.rattail_record_changes = True
-
-    if log_pool_status:
-        engine.rattail_log_pool_status = log_pool_status
-
-    return engine
-
-
 def get_engines(config, section='rattail.db'):
     """
-    Fetch all database engines defined within a given config section.
-
-    :returns: A dictionary of SQLAlchemy engine instances, with keys matching
-       those found in config.
+    DEPRECATED; please use
+    :func:`wuttjamaican:wuttjamaican.db.conf.get_engines()` instead.
     """
-    keys = config.get(section, 'keys', usedb=False)
-    if keys:
-        keys = parse_list(keys)
-    else:
-        keys = ['default']
-
-    engines = OrderedDict()
-    cfg = config.get_dict(section)
-    for key in keys:
-        key = key.strip()
-        try:
-            engines[key] = engine_from_config(cfg, prefix='{0}.'.format(key))
-        except KeyError:
-            if key == 'default':
-                try:
-                    engines[key] = engine_from_config(cfg, prefix='sqlalchemy.')
-                except KeyError:
-                    pass
-    return engines
+    warnings.warn("rattail.db.config.get_engines() is deprecated; "
+                  "please use wuttjamaican.db.get_engines() instead",
+                  DeprecationWarning, stacklevel=2)
+    from wuttjamaican.db import get_engines
+    return get_engines(config, section)
 
 
-# TODO: Deprecate/remove this.
 def get_default_engine(config, section='rattail.db'):
     """
-    Fetch the default database engine defined in the given config object for a
-    given section.
-
-    :param config: A ``ConfigParser`` instance containing app configuration.
-
-    :type section: string
-    :param section: Optional section name within which the configuration
-       options are defined.  If not specified, ``'rattail.db'`` is assumed.
-
-    :returns: A SQLAlchemy engine instance, or ``None``.
-
-    .. note::
-       This function calls :func:`get_engines()` for the heavy lifting; see
-       that function for more details on how the engine configuration is read.
+    DEPRECATED; please use
+    :func:`wuttjamaican:wuttjamaican.db.conf.get_engines()` instead.
     """
-    return get_engines(config, section=section).get('default')
+    warnings.warn("rattail.db.config.get_default_engine() is deprecated; "
+                  "please use wuttjamaican.db.get_engines() instead",
+                  DeprecationWarning, stacklevel=2)
+    from wuttjamaican.db import get_engines
+    return get_engines(config, section).get('default')
 
 
 # TODO: Deprecate/remove this.
@@ -177,12 +91,13 @@ def configure_versioning(config, force=False, manager=None, plugins=None, **kwar
             kwargs['plugins'] = plugins
         else:
             kwargs['plugins'] = [TransactionMetaPlugin(), RattailPlugin()]
-        log.info("enabling Continuum versioning")
+        log.debug("enabling Continuum versioning")
         continuum.make_versioned(**kwargs)
 
         # TODO: is this the best way/place to confirm versioning?
+        app = config.get_app()
         try:
-            model = config.get_model()
+            model = app.model
             configure_mappers()
             transaction_class = continuum.transaction_class(model.User)
             config.versioning_has_been_enabled = True
@@ -190,3 +105,56 @@ def configure_versioning(config, force=False, manager=None, plugins=None, **kwar
             raise RuntimeError("Versioning is enabled and configured, but is not functional!  "
                                "This probably means the code import sequence is faulty somehow.  "
                                "Please investigate ASAP.")
+
+
+def make_engine_from_config(
+        config_dict,
+        prefix='sqlalchemy.',
+        **kwargs):
+    """
+    This is the same as
+    :func:`wuttjamaican:wuttjamaican.db.conf.make_engine_from_config()`
+    except Rattail may customize the engine a bit further:
+
+    The engine can be told to "record changes" for sake of
+    datasync; for instance:
+
+    .. code-block:: ini
+
+       [rattail.db]
+       default.url = sqlite:///
+       default.record_changes = true
+
+    And/or the engine can be told to log its SQLAlchemy connection
+    pool status:
+
+    .. code-block:: ini
+
+       [rattail.db]
+       default.url = sqlite:///
+       default.log_pool_status = true
+    """
+    config_dict = dict(config_dict)
+
+    # stash flag for recording changes
+    record_changes = False
+    key = f'{prefix}record_changes'
+    if key in config_dict:
+        record_changes = parse_bool(config_dict.pop(key))
+
+    # stash flag for logging db pool status
+    log_pool_status = False
+    key = f'{prefix}log_pool_status'
+    if key in config_dict:
+        log_pool_status = parse_bool(config_dict.pop(key))
+
+    # make engine per usual
+    engine = wutta_make_engine_from_config(config_dict, prefix=prefix, **kwargs)
+
+    # then apply flags from stash
+    if record_changes:
+        engine.rattail_record_changes = True
+    if log_pool_status:
+        engine.rattail_log_pool_status = log_pool_status
+
+    return engine
