@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,22 +24,23 @@
 Core Data Stuff
 """
 
-from __future__ import unicode_literals, absolute_import
+import warnings
 
 import sqlalchemy as sa
 
-from rattail.core import get_uuid
-
 
 def uuid_column(*args, **kwargs):
     """
-    Returns a UUID column for use as a table's primary key.
+    DEPRECATED; use :func:`rattail.db.model.core.uuid_column()`
+    instead.
     """
+    warnings.warn("rattail.db.core.uuid_column() is deprecated; "
+                  "please use rattail.db.model.uuid_column() instead",
+                  DeprecationWarning, stacklevel=2)
 
-    kwargs.setdefault('primary_key', True)
-    kwargs.setdefault('nullable', False)
-    kwargs.setdefault('default', get_uuid)
-    return sa.Column(sa.String(length=32), *args, **kwargs)
+    from rattail.db.model import uuid_column
+
+    return uuid_column(*args, **kwargs)
 
 
 def filename_column(*args, **kwargs):
