@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2023 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -38,9 +38,9 @@ from sqlalchemy.orm import relationship, object_session
 from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy.ext.orderinglist import ordering_list
 
-from rattail.db.core import uuid_column, filename_column
+from rattail.db.core import filename_column
 from rattail.db.types import GPCType, JSONTextDict
-from rattail.db.model import User, Product
+from rattail.db.model import uuid_column, User, Product
 from rattail.time import make_utc
 
 
@@ -283,7 +283,7 @@ class BatchMixin(object):
         """
         warnings.warn("This method has been deprecated; please see/use "
                       "BatchHandler.delete_extra_data() instead",
-                      DeprecationWarning)
+                      DeprecationWarning, stacklevel=2)
 
         # TODO: should this logic be in the handler instead?
         path = config.batch_filepath(self.batch_key, self.uuid)
