@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2023 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -34,13 +34,15 @@ except ImportError:
     from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.ext.associationproxy import association_proxy
 
+from wuttjamaican.db.model.base import naming_convention, uuid_column, uuid_fk_column
+
 from rattail.core import Object
 from rattail.time import make_utc
 
 # These are imported because most sibling modules import them *from* here (if
 # that makes sense).  Probably need to think harder about the "best" place for
 # these things to live.
-from rattail.db.core import uuid_column, getset_factory
+from rattail.db.core import getset_factory
 from rattail.db.types import GPCType
 
 
@@ -105,7 +107,9 @@ class ModelBase(Object):
             getset_factory=getset_factory))
 
 
-Base = declarative_base(cls=ModelBase)
+metadata = sa.MetaData(naming_convention=naming_convention)
+
+Base = declarative_base(metadata=metadata, cls=ModelBase)
 
 
 class Setting(Base):
