@@ -25,6 +25,7 @@ Data Models for Customers
 """
 
 import datetime
+import warnings
 
 import sqlalchemy as sa
 from sqlalchemy import orm
@@ -44,6 +45,11 @@ class Customer(ContactMixin, Base):
     Customer accounts may consist of more than one person, in some cases.
     """
     __tablename__ = 'customer'
+    __table_args__ = (
+        sa.ForeignKeyConstraint(['account_holder_uuid'],
+                                ['person.uuid'],
+                                name='customer_fk_account_holder'),
+    )
     __versioned__ = {}
 
     uuid = uuid_column()
@@ -59,6 +65,22 @@ class Customer(ContactMixin, Base):
     """)
 
     name = sa.Column(sa.String(length=255))
+
+    account_holder_uuid = sa.Column(sa.String(length=32), nullable=True)
+    account_holder = orm.relationship(
+        Person, doc="""
+        Reference to the account holder (person), if applicable.
+        """,
+        cascade_backrefs=False,
+        backref=orm.backref(
+            # TODO: `customers` would be a better backref name, but
+            # that is already taken for CustomerPerson relationship
+            'customer_accounts', doc="""
+            List of customer records for which this person is the
+            account holder.
+            """,
+            cascade_backrefs=False))
+
     email_preference = sa.Column(sa.Integer())
 
     wholesale = sa.Column(sa.Boolean(), nullable=True, doc="""
@@ -103,30 +125,49 @@ class Customer(ContactMixin, Base):
     @property
     def employee(self):
         """
+        DEPRECATED
+
         Return the employee associated with the customer, if any.  Assumes a
         certain "typical" relationship path.
         """
+        warnings.warn("customer.employee is deprecated; "
+                      "please use app.get_employee(customer) instead",
+                      DeprecationWarning, stacklevel=2)
         if self.person:
             return self.person.employee
 
     def first_person(self):
         """
+        DEPRECATED
+
         Convenience method to retrieve the "first" Person record which is
         associated with this customer, or ``None``.
         """
+        warnings.warn("customer.first_person() is deprecated; "
+                      "please use app.get_person(customer) instead",
+                      DeprecationWarning, stacklevel=2)
+        if self.account_holder:
+            return self.account_holder
+        if self.shoppers:
+            return self.shoppers[0].person
         if self.people:
             return self.people[0]
 
     def only_person(self, require=True):
         """
+        DEPRECATED
+
         Convenience method to retrieve the one and only Person record which is
         associated with this customer.  An error will be raised if there is not
         exactly one person associated.
         """
-        if len(self.people) > 1 or (require and not self.people):
-            raise ValueError("customer {} should have 1 person but instead has {}: {}".format(
-                self.uuid, len(self.people), self))
-        return self.people[0] if self.people else None
+        warnings.warn("customer.only_person() is deprecated; "
+                      "please use app.get_person(customer) instead",
+                      DeprecationWarning, stacklevel=2)
+        person = self.first_person()
+        if require and not person:
+            raise ValueError(f"customer {self.uuid} has no person")
+        return person
 
     def only_member(self, require=True):
         """
@@ -302,6 +343,115 @@ Customer.groups = association_proxy(
     creator=lambda g: CustomerGroupAssignment(group=g))
 
 
+class CustomerShopper(Base):
+    """
+    Represents a "shopper" on a customer account.  Most customer
+    accounts will have at least one of these (shopper #1) who is the
+    account holder.
+    """
+    __tablename__ = 'customer_shopper'
+    __table_args__ = (
+        sa.ForeignKeyConstraint(['customer_uuid'],
+                                ['customer.uuid'],
+                                name='customer_shopper_fk_customer'),
+        sa.ForeignKeyConstraint(['person_uuid'],
+                                ['person.uuid'],
+                                name='customer_shopper_fk_person'),
+        sa.UniqueConstraint('customer_uuid', 'shopper_number',
+                            name='customer_shopper_uq_shopper_number'),
+        sa.Index('customer_shopper_ix_customer', 'customer_uuid'),
+        sa.Index('customer_shopper_ix_person', 'person_uuid'),
+    )
+    __versioned__ = {}
+
+    uuid = uuid_column()
+
+    customer_uuid = sa.Column(sa.String(length=32), nullable=False)
+    customer = orm.relationship(
+        Customer, doc="""
+        Reference to the customer account to which the shopper belongs.
+        """,
+        cascade_backrefs=False,
+        backref=orm.backref(
+            'shoppers', doc="""
+            List of all shoppers (past and present) for the customer.
+            """,
+            order_by='CustomerShopper.shopper_number',
+            cascade_backrefs=False))
+
+    person_uuid = sa.Column(sa.String(length=32), nullable=False)
+    person = orm.relationship(
+        Person,
+        doc="""
+        Reference to the person who "is" this shopper.
+        """,
+        backref=orm.backref(
+            'customer_shoppers', doc="""
+            List of all shopper records for this person, under various
+            customer accounts.
+            """,
+            cascade_backrefs=False))
+
+    shopper_number = sa.Column(sa.Integer(), nullable=False, doc="""
+    Sequence number (starting with 1) for this shopper record, within
+    the context of the customer account.
+    """)
+
+    active = sa.Column(sa.Boolean(), nullable=True, doc="""
+    Whether this shopper record is currently active for the customer.
+    """)
+
+    def __str__(self):
+        return f"#{self.shopper_number} - {self.person}"
+
+    def get_current_history(self):
+        """
+        Returns the "current" history record for the shopper, if
+        applicable.  Note that this history record is not necessarily
+        "active" - it's just the most recent.
+        """
+        if self.history:
+            return self.history[-1]
+
+
+class CustomerShopperHistory(Base):
+    """
+    History records for customer shoppers.
+    """
+    __tablename__ = 'customer_shopper_history'
+    __table_args__ = (
+        sa.ForeignKeyConstraint(['shopper_uuid'],
+                                ['customer_shopper.uuid'],
+                                name='customer_shopper_history_fk_shopper'),
+        sa.Index('customer_shopper_history_ix_shopper', 'shopper_uuid'),
+    )
+    __versioned__ = {}
+
+    uuid = uuid_column()
+
+    shopper_uuid = sa.Column(sa.String(length=32), nullable=False)
+    shopper = orm.relationship(
+        CustomerShopper, doc="""
+        Reference to the shopper record to which this history pertains.
+        """,
+        cascade_backrefs=False,
+        backref=orm.backref(
+            'history',
+            order_by='(CustomerShopperHistory.start_date, CustomerShopperHistory.end_date)',
+            cascade_backrefs=False,
+            doc="""
+            Sequence of history records for the shopper.
+            """))
+
+    start_date = sa.Column(sa.Date(), nullable=True, doc="""
+    Date on which the shopper became active for the customer.
+    """)
+
+    end_date = sa.Column(sa.Date(), nullable=True, doc="""
+    Date on which the shopper became inactive, if applicable.
+    """)
+
+
 class CustomerPerson(Base):
     """
     Represents the association between a person and a customer account.
