@@ -162,9 +162,7 @@ class CustomerOrder(CustomerOrderBase, Base):
         """)
 
     def __str__(self):
-        if self.id:
-            return "#{}".format(self.id)
-        return "(pending)"
+        return str(self.id or "(pending)")
 
 
 class CustomerOrderItemBase(object):
@@ -236,7 +234,7 @@ class CustomerOrderItemBase(object):
     :attr:`Product.size`.
     """)
 
-    product_weighed = sa.Column(sa.String(length=4), nullable=True, doc="""
+    product_weighed = sa.Column(sa.Boolean(), nullable=True, doc="""
     Flag indicating whether the product is sold by weight.  This should be a
     cache of :attr:`Product.weighed`.
     """)
@@ -316,6 +314,13 @@ class CustomerOrderItemBase(object):
     Full price (not including tax etc.) which the customer is asked to pay for the item.
     """)
 
+    special_order = sa.Column(sa.Boolean(), nullable=True, doc="""
+    If set, indicates this item is a "special order" - whatever that
+    means to you.  Most typically, this means the item is not normally
+    carried by the store, but presumably the store *will* order it on
+    behalf of the customer.
+    """)
+
     price_needs_confirmation = sa.Column(sa.Boolean(), nullable=True, doc="""
     Flag indicating that the price for this item should be confirmed
     by someone, before the order advances to the procurement phase.
@@ -336,7 +341,7 @@ class CustomerOrderItemBase(object):
     """)
 
     def __str__(self):
-        return str(self.product or "(no product)")
+        return str(self.product or self.pending_product or "(no product)")
 
 
 class CustomerOrderItem(CustomerOrderItemBase, Base):
@@ -365,12 +370,27 @@ class CustomerOrderItem(CustomerOrderItemBase, Base):
     single order.
     """)
 
+    flagged = sa.Column(sa.Boolean(), nullable=True, doc="""
+    Simple flagging mechanism to indicate order items which need
+    closer attention, special handling etc.
+    """)
+
     status_code = sa.Column(sa.Integer(), nullable=False)
 
     status_text = sa.Column(sa.String(length=255), nullable=True, doc="""
     Text which may briefly explain the batch status code, if needed.
     """)
 
+    contact_attempts = sa.Column(sa.Integer(), nullable=True, doc="""
+    Number of times staff has tried to contact customer regarding this
+    item, if applicable.
+    """)
+
+    last_contacted = sa.Column(sa.DateTime(), nullable=True, doc="""
+    Date/time when staff last tried to contact customer regarding this
+    item, if applicable.
+    """)
+
     def add_event(self, type_code, user, **kwargs):
         """
         Convenience method to add an event for the order item.
@@ -424,6 +444,7 @@ class CustomerOrderItemEvent(Base):
     """)
 
 
+# TODO: deprecate / remove this?  not really used currently
 class CustomerOrderItemNote(Note):
     """
     Represents a note attached to an order item.
