@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,17 +24,13 @@
 Data Models for DataSync Daemon
 """
 
-from __future__ import unicode_literals
-
 import datetime
 
-import six
 import sqlalchemy as sa
 
 from rattail.db.model import Base, uuid_column
 
 
-@six.python_2_unicode_compatible
 class DataSyncChange(Base):
     """
     Represents a change obtained from a DataSync watcher thread, and destined
