@@ -25,6 +25,7 @@ Data Models for Employees
 """
 
 import datetime
+import warnings
 
 import sqlalchemy as sa
 from sqlalchemy import orm
@@ -96,12 +97,20 @@ class Employee(Base):
 
     @property
     def customers(self):
+        warnings.warn("employee.customers is deprecated; please use "
+                      "clientele.get_customers_for_account_holder() instead",
+                      DeprecationWarning, stacklevel=2)
         return self.person.customers
 
     def only_customer(self, require=True):
         """
+        DEPRECATED
+
         Convenience method which invokes ``self.person.only_customer()``
         """
+        warnings.warn("employee.only_customer() is deprecated; "
+                      "please use app.get_customer() instead",
+                      DeprecationWarning, stacklevel=2)
         return self.person.only_customer(require=require)
 
     def add_email_address(self, address, type='Home'):
