@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,8 @@
 Models for generic data export history
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.ext.declarative import declared_attr
@@ -36,7 +33,6 @@ from sqlalchemy.ext.declarative import declared_attr
 from rattail.db.model import uuid_column, User
 
 
-@six.python_2_unicode_compatible
 class ExportMixin(object):
     """
     Mixin for all generic export models
