@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,8 @@
 Data Models for Label Printing
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import warnings
 
-import six
 import sqlalchemy as sa
 from sqlalchemy.orm import object_session
 
@@ -36,7 +33,6 @@ from .core import Base, uuid_column
 from rattail.util import load_object
 
 
-@six.python_2_unicode_compatible
 class LabelProfile(Base):
     """
     Represents a collection of settings for product label printing.
@@ -96,7 +92,7 @@ class LabelProfile(Base):
     def get_formatter(self, config): # pragma: no cover
         warnings.warn("method is deprecated, please use "
                       "LabelHandler.get_formatter() method instead",
-                      DeprecationWarning)
+                      DeprecationWarning, stacklevel=2)
 
         app = config.get_app()
         label_handler = app.get_label_handler()
@@ -105,7 +101,7 @@ class LabelProfile(Base):
     def get_printer(self, config): # pragma: no cover
         warnings.warn("method is deprecated, please use "
                       "LabelHandler.get_printer() method instead",
-                      DeprecationWarning)
+                      DeprecationWarning, stacklevel=2)
 
         app = config.get_app()
         label_handler = app.get_label_handler()
@@ -114,7 +110,7 @@ class LabelProfile(Base):
     def get_printer_setting(self, name): # pragma: no cover
         warnings.warn("method is deprecated, please use "
                       "LabelHandler.get_printer_setting() method instead",
-                      DeprecationWarning)
+                      DeprecationWarning, stacklevel=2)
 
         from rattail.db.api import get_setting
         if self.uuid is None:
@@ -126,7 +122,7 @@ class LabelProfile(Base):
     def save_printer_setting(self, name, value): # pragma: no cover
         warnings.warn("method is deprecated, please use "
                       "LabelHandler.save_printer_setting() method instead",
-                      DeprecationWarning)
+                      DeprecationWarning, stacklevel=2)
 
         from rattail.db.api import save_setting
         session = object_session(self)
