@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,21 +24,21 @@
 Data Models for Organization etc.
 """
 
-from __future__ import unicode_literals, absolute_import
-
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 
 from rattail.db.model import Base, uuid_column
 
 
-@six.python_2_unicode_compatible
 class Department(Base):
     """
     Represents an organizational department.
     """
     __tablename__ = 'department'
+    __table_args__ = (
+        sa.ForeignKeyConstraint(['tax_uuid'], ['tax.uuid'],
+                                name='department_fk_tax'),
+    )
     __versioned__ = {}
 
     uuid = uuid_column()
@@ -73,11 +73,35 @@ class Department(Base):
     Whether products belonging to this department may be deleted.
     """)
 
+    tax_uuid = sa.Column(sa.String(length=32), nullable=True)
+    tax = orm.relationship(
+        'Tax',
+        doc="""
+        Reference to the tax which should "typically" be incurred for
+        sales to this department, if applicable.
+        """)
+
+    food_stampable = sa.Column(sa.Boolean(), nullable=True, doc="""
+    Flag indicating whether food stamps are a valid form of payment
+    for the department, if applicable.
+    """)
+
+    default_custorder_discount = sa.Column(sa.Numeric(precision=5, scale=3), nullable=True, doc="""
+    Default item discount for customer orders, if applicable.
+    """)
+
+    subdepartments = orm.relationship(
+        'Subdepartment',
+        order_by='Subdepartment.name',
+        cascade_backrefs=False,
+        backref=orm.backref(
+            'department',
+            cascade_backrefs=False))
+
     def __str__(self):
         return self.name or ''
 
 
-@six.python_2_unicode_compatible
 class Subdepartment(Base):
     """
     Represents an organizational subdepartment.
@@ -97,13 +121,6 @@ class Subdepartment(Base):
         return self.name or ''
 
 
-Department.subdepartments = orm.relationship(
-    Subdepartment,
-    backref='department',
-    order_by=Subdepartment.name)
-
-
-@six.python_2_unicode_compatible
 class Category(Base):
     """
     Represents an organizational category for products.
@@ -158,16 +175,9 @@ class Family(Base):
     """)
 
     def __str__(self):
-        if six.PY2:
-            return (self.name or '').encode('utf_8')
         return self.name or ''
 
-    if six.PY2:
-        def __unicode__(self):
-            return self.name or ''
 
-
-@six.python_2_unicode_compatible
 class ReportCode(Base):
     """
     Represents an organizational "report code" for products.
@@ -188,7 +198,6 @@ class ReportCode(Base):
         return "{} - {}".format(self.code, self.name or '')
 
 
-@six.python_2_unicode_compatible
 class DepositLink(Base):
     """
     Represents a bottle or similar deposit, to which an item may be linked.
