@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2023 Lance Edgar
+#  Copyright © 2010-20234 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -25,6 +25,7 @@ Data Models for People
 """
 
 import datetime
+import warnings
 
 import sqlalchemy as sa
 from sqlalchemy import orm
@@ -60,9 +61,25 @@ class Person(ContactMixin, Base):
     }
 
     uuid = uuid_column()
-    first_name = sa.Column(sa.String(length=50), nullable=True)
-    middle_name = sa.Column(sa.String(length=50), nullable=True)
-    last_name = sa.Column(sa.String(length=50), nullable=True)
+
+    first_name = sa.Column(sa.String(length=50), nullable=True, doc="""
+    Person's "true" first name.
+    """)
+
+    preferred_first_name = sa.Column(sa.String(length=50), nullable=True, doc="""
+    Preferred first name for the person, if applicable.  When present,
+    this may be used *instead of* the ``first_name`` value, when
+    displaying the person's full name etc.
+    """)
+
+    middle_name = sa.Column(sa.String(length=50), nullable=True, doc="""
+    Person's middle name (or initial), if applicable/known.
+    """)
+
+    last_name = sa.Column(sa.String(length=50), nullable=True, doc="""
+    Person's last name.
+    """)
+
     # TODO: rename this to 'full_name' at some point...?
     display_name = sa.Column(sa.String(length=100), nullable=True)
 
@@ -115,14 +132,31 @@ class Person(ContactMixin, Base):
 
     def only_customer(self, require=True):
         """
+        DEPRECATED
+
         Convenience method to retrieve the one and only ``Customer`` record
         which is associated with this person.  An error will be raised if there
         is not exactly one customer associated.
         """
-        if len(self.customers) > 1 or (require and not self.customers):
-            raise ValueError("person {} should have 1 customer but instead has {}: {}".format(
-                self.uuid, len(self.customers), self))
-        return self.customers[0] if self.customers else None
+        warnings.warn("person.only_customer() is deprecated; please "
+                      "use app.get_customer(person) instead",
+                      DeprecationWarning, stacklevel=2)
+
+        # TODO: all 3 options below are indeterminate, since it's
+        # *possible* for a person to hold multiple accounts
+        # etc. but not sure how to fix in a generic way?  maybe
+        # just everyone must override as needed
+        if self.customer_accounts:
+            return self.customer_accounts[0]
+        for shopper in self.customer_shoppers:
+            if shopper.shopper_number == 1:
+                return shopper.customer
+        # legacy fallback
+        if self.customers:
+            return self.customers[0]
+
+        if require:
+            raise ValueError(f"person {self.uuid} has no customer")
 
 
 class PersonContactInfoMixin(object):
