@@ -129,9 +129,9 @@ class Tax(Base):
     """)
 
     def __str__(self):
-        if self.description:
-            return self.description
-        return "{} ({}%)".format(self.code, pretty_quantity(self.rate))
+        if self.rate is not None:
+            return f"{self.description} {self.rate:0.3f} %"
+        return self.description or ''
 
 
 class Product(Base):
@@ -820,6 +820,19 @@ class ProductPrice(Base):
     pack_price = sa.Column(sa.Numeric(precision=8, scale=3))
     pack_multiple = sa.Column(sa.Integer())
 
+    def __str__(self):
+        text = ""
+        if self.price:
+            text = f"${self.price:0.2f}"
+            if self.multiple:
+                text += f"/{self.multiple}"
+        if self.pack_price:
+            pack_text = f"${self.pack_price:0.2f}"
+            if self.pack_multiple:
+                pack_text += f"/{self.pack_multiple}"
+            text += f" ({pack_text})"
+        return text
+
     def active_now(self):
         """
         Returns boolean indicating whether the price is currently active,
@@ -981,7 +994,7 @@ class ProductVolatile(Base):
     a cache, for sake of SQL access to the values.
     """)
 
-    true_margin = sa.Column(sa.Numeric(precision=9, scale=5), nullable=True, doc="""
+    true_margin = sa.Column(sa.Numeric(precision=12, scale=5), nullable=True, doc="""
     "True" profit margin for the "regular" unit price vs. the "true"
     unit cost (:attr:`true_cost`).  This is expressed as a
     human-friendly percentage value, e.g. ``37.5`` (instead of
@@ -995,10 +1008,14 @@ class PendingProduct(Base):
     """
     __tablename__ = 'pending_product'
     __table_args__ = (
-        sa.ForeignKeyConstraint(['user_uuid'], ['user.uuid'], name='pending_product_fk_user'),
+        sa.ForeignKeyConstraint(['product_uuid'], ['product.uuid'], name='pending_product_fk_product'),
         sa.ForeignKeyConstraint(['department_uuid'], ['department.uuid'], name='pending_product_fk_department'),
         sa.ForeignKeyConstraint(['brand_uuid'], ['brand.uuid'], name='pending_product_fk_brand'),
         sa.ForeignKeyConstraint(['vendor_uuid'], ['vendor.uuid'], name='pending_product_fk_vendor'),
+        sa.ForeignKeyConstraint(['user_uuid'], ['user.uuid'],
+                                name='pending_product_fk_user'),
+        sa.ForeignKeyConstraint(['resolved_by_uuid'], ['user.uuid'],
+                                name='pending_product_fk_resolved_by'),
     )
 
     uuid = uuid_column()
@@ -1006,6 +1023,7 @@ class PendingProduct(Base):
     user_uuid = sa.Column(sa.String(length=32), nullable=False)
     user = orm.relationship(
         'User',
+        foreign_keys=[user_uuid],
         doc="""
         Reference to the :class:`~rattail:rattail.db.model.User` who
         first entered the record.
@@ -1016,6 +1034,15 @@ class PendingProduct(Base):
     Timestamp when the record was first created.
     """)
 
+    product_uuid = sa.Column(sa.String(length=32), nullable=True)
+    product = orm.relationship(
+        Product,
+        cascade_backrefs=False,
+        doc="""
+        Reference to the final :class:`~rattail.db.model.Product` record,
+        if applicable.
+        """)
+
     # Product fields
     upc = sa.Column(GPCType(), nullable=True)
     scancode = sa.Column(sa.String(length=14), nullable=True)
@@ -1050,6 +1077,19 @@ class PendingProduct(Base):
     Status indicator for the new product record.
     """)
 
+    resolved = sa.Column(sa.DateTime(), nullable=True, doc="""
+    Timestamp when the record was resolved.
+    """)
+
+    resolved_by_uuid = sa.Column(sa.String(length=32), nullable=True)
+    resolved_by = orm.relationship(
+        'User',
+        foreign_keys=[resolved_by_uuid],
+        doc="""
+        Reference to the :class:`~rattail:rattail.db.model.User` who
+        resolved the record.
+        """)
+
     @property
     def full_description(self):
         return make_full_description(self.brand_name,
