@@ -264,6 +264,14 @@ class PurchaseItemBase(object):
     vendor invoice.
     """)
 
+    invoice_date = sa.Column(sa.Date(), nullable=True, doc="""
+    Invoice date, if applicable.
+    """)
+
+    invoice_number = sa.Column(sa.String(length=20), nullable=True, doc="""
+    Invoice number, e.g. for cross-reference with another system.
+    """)
+
     invoice_line_number = sa.Column(sa.Integer(), nullable=True, doc="""
     Line number from the invoice if known, for cross-reference.
     """)
@@ -503,7 +511,7 @@ class PurchaseCreditBase(object):
         if self.credit_type == 'mispick' and self.mispick_product:
             qty += " ({})".format(self.mispick_product)
         if self.invoice_total:
-            return "{} = ${:0.2f}".format(qty, self.invoice_total)
+            return "{} = ${:0.2f}".format(qty, self.credit_total)
         return qty
 
 
