@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,18 +24,14 @@
 Data models for tempmon
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 
 from rattail.db.model import Base, uuid_column
 
 
-@six.python_2_unicode_compatible
 class TempmonClient(Base):
     """
     Represents a tempmon client.
@@ -60,7 +56,6 @@ class TempmonClient(Base):
         return [probe for probe in self.probes if probe.enabled]
 
 
-@six.python_2_unicode_compatible
 class TempmonProbe(Base):
     """
     Represents a probe connected to a tempmon client.
@@ -82,6 +77,7 @@ class TempmonProbe(Base):
         """,
         backref=orm.backref(
             'probes',
+            cascade_backrefs=False,
             doc="""
             List of probes connected to this client.
             """))
@@ -107,7 +103,6 @@ class TempmonProbe(Base):
         return str(self.description or '')
 
 
-@six.python_2_unicode_compatible
 class TempmonReading(Base):
     """
     Represents a single tempurate reading from a tempmon probe.
