@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,18 +24,14 @@
 Data models for scheduled app upgrades
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 
 from rattail.db.model import Base, uuid_column, User
 
 
-@six.python_2_unicode_compatible
 class Upgrade(Base):
     """
     Represents a scheduled app upgrade.
@@ -125,7 +121,8 @@ class UpgradeRequirement(Base):
     upgrade = orm.relationship(
         Upgrade,
         backref=orm.backref(
-            'requirements'))
+            'requirements',
+            cascade_backrefs=False))
 
     package = sa.Column(sa.String(length=255), nullable=False, doc="""
     Package name as found on PyPI (or at least interpretable by pip).
