@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2023 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -25,12 +25,13 @@ Data Models for Users & Permissions
 """
 
 import datetime
+import warnings
 
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.ext.associationproxy import association_proxy
 
-from rattail.db.model import Base, uuid_column, getset_factory, Person
+from rattail.db.model import Base, uuid_column, uuid_fk_column, getset_factory, Person
  
 
 class Role(Base):
@@ -38,14 +39,11 @@ class Role(Base):
     Represents a role within the system; used to manage permissions.
     """
     __tablename__ = 'role'
-    __table_args__ = (
-        sa.UniqueConstraint('name', name='role_uq_name'),
-    )
     __versioned__ = {}
 
     uuid = uuid_column()
 
-    name = sa.Column(sa.String(length=100), nullable=False, doc="""
+    name = sa.Column(sa.String(length=100), nullable=False, unique=True, doc="""
     Name for the role.  Each role must have a name, which must be unique.
     """)
 
@@ -130,12 +128,10 @@ class Permission(Base):
     Represents permission a role has to do a particular thing.
     """
     __tablename__ = 'permission'
-    __table_args__ = (
-        sa.ForeignKeyConstraint(['role_uuid'], ['role.uuid'], name='permission_fk_role'),
-        )
     # __versioned__ = {}
 
-    role_uuid = sa.Column(sa.String(length=32), primary_key=True)
+    role_uuid = uuid_fk_column('role.uuid', primary_key=True, nullable=False)
+
     permission = sa.Column(sa.String(length=254), primary_key=True)
 
     def __str__(self):
@@ -161,18 +157,16 @@ class User(Base):
     """
     __tablename__ = 'user'
     __table_args__ = (
-        sa.ForeignKeyConstraint(['person_uuid'], ['person.uuid'], name='user_fk_person'),
-        sa.UniqueConstraint('username', name='user_uq_username'),
         sa.Index('user_ix_person', 'person_uuid'),
     )
     __versioned__ = {'exclude': ['password', 'salt', 'last_login']}
 
     uuid = uuid_column()
-    username = sa.Column(sa.String(length=25), nullable=False)
+    username = sa.Column(sa.String(length=25), nullable=False, unique=True)
     password = sa.Column(sa.String(length=60))
     salt = sa.Column(sa.String(length=29))
 
-    person_uuid = sa.Column(sa.String(length=32))
+    person_uuid = uuid_fk_column('person.uuid', nullable=True)
     person = orm.relationship(
         Person,
         uselist=False,
@@ -201,6 +195,12 @@ class User(Base):
     as off-limits from the general active flag sync.
     """)
 
+    prevent_password_change = sa.Column(sa.Boolean(), nullable=True, doc="""
+    If set, this user cannot change their own password, *and* the
+    password is not editable when e.g. a manager edits this user
+    record.  So if set, only root can change this user's password.
+    """)
+
     local_only = sa.Column(sa.Boolean(), nullable=True, doc="""
     Flag indicating the user account is somehow specific to the "local" app
     node etc. and should not be synced elsewhere.
@@ -230,8 +230,13 @@ class User(Base):
     @property
     def employee(self):
         """
+        DEPRECATED
+
         Reference to the :class:`Employee` associated with the user, if any.
         """
+        warnings.warn("user.employee is deprecated; please use "
+                      "app.get_employee(user) instead",
+                      DeprecationWarning, stacklevel=2)
         if self.person:
             return self.person.employee
 
@@ -240,6 +245,10 @@ class User(Base):
         Returns "short name" for the user.  This is for convenience of mobile
         view, at least...
         """
+        warnings.warn("user.get_short_name() is deprecated; please use "
+                      "AuthHandler.get_short_display_name(user) instead",
+                      DeprecationWarning, stacklevel=2)
+
         # TODO: this should reference employee.short_name
         employee = self.employee
         if employee and employee.display_name:
@@ -256,11 +265,16 @@ class User(Base):
 
     def get_email_address(self):
         """
+        DEPRECATED
+
         Returns the primary email address for the user (as unicode string), or
         ``None``.  Note that currently there is no direct association between a
         User and an EmailAddress, so the Person and Customer relationships are
         navigated in an attempt to locate an address.
         """
+        warnings.warn("user.get_email_address() is deprecated; please "
+                      "use app.get_contact_email_address(user) instead",
+                      DeprecationWarning, stacklevel=2)
         if self.person:
             if self.person.email:
                 return self.person.email.address
@@ -271,19 +285,28 @@ class User(Base):
     @property
     def email_address(self):
         """
+        DEPRECATED
+
         Convenience attribute which invokes :meth:`get_email_address()`.
 
         .. note::
            The implementation of this may change some day, e.g. if the User is
            given an association to EmailAddress in the data model.
         """
+        warnings.warn("user.email_address is deprecated; please "
+                      "use app.get_contact_email_address(user) instead",
+                      DeprecationWarning, stacklevel=2)
         return self.get_email_address()
 
     def is_admin(self):
         """
-        Convenience method to determine if current user is a member of the
-        Administrator role.
+        DEPRECATED; use
+        :meth:`rattail.auth.AuthHandler.user_is_admin()` instead.
         """
+        warnings.warn("user.is_admin() is deprecated; "
+                      "please use AuthHandler.user_is_admin(user) instead",
+                      DeprecationWarning, stacklevel=2)
+
         from rattail.db.auth import administrator_role
 
         session = orm.object_session(self)
@@ -304,16 +327,12 @@ class UserRole(Base):
     Represents the association between a :class:`User` and a :class:`Role`.
     """
     __tablename__ = 'user_x_role'
-    __table_args__ = (
-        sa.ForeignKeyConstraint(['user_uuid'], ['user.uuid'], name='user_x_role_fk_user'),
-        sa.ForeignKeyConstraint(['role_uuid'], ['role.uuid'], name='user_x_role_fk_role'),
-        )
     __versioned__ = {}
 
     uuid = uuid_column()
-    user_uuid = sa.Column(sa.String(length=32), nullable=False)
+    user_uuid = uuid_fk_column('user.uuid', nullable=False)
 
-    role_uuid = sa.Column(sa.String(length=32), nullable=False)
+    role_uuid = uuid_fk_column('role.uuid', nullable=False)
     role = orm.relationship(Role, back_populates='_users')
 
 
@@ -360,3 +379,50 @@ class UserEvent(Base):
     occurred = sa.Column(sa.DateTime(), nullable=True, default=datetime.datetime.utcnow, doc="""
     Timestamp at which the event occurred.
     """)
+
+
+class UserAPIToken(Base):
+    """
+    User authentication token for use with Tailbone API
+    """
+    __tablename__ = 'user_api_token'
+    __table_args__ = (
+        sa.ForeignKeyConstraint(['user_uuid'], ['user.uuid'],
+                                name='user_api_token_fk_user'),
+    )
+    __versioned__ = {}
+    model_title = "API Token"
+    model_title_plural = "API Tokens"
+
+    uuid = uuid_column()
+
+    user_uuid = sa.Column(sa.String(length=32), nullable=False, doc="""
+    Reference to the User associated with the token.
+    """)
+    user = orm.relationship(
+        'User',
+        doc="""
+        Reference to the User associated with the token.
+        """,
+        backref=orm.backref(
+            'api_tokens',
+            cascade_backrefs=False,
+            order_by='UserAPIToken.created',
+            doc="""
+            List of API tokens for the user.
+            """))
+
+    description = sa.Column(sa.String(length=255), nullable=False, doc="""
+    Description of the token.
+    """)
+
+    token_string = sa.Column(sa.String(length=255), nullable=False, doc="""
+    Token string, to be used by API clients.
+    """)
+
+    created = sa.Column(sa.DateTime(), nullable=False, default=datetime.datetime.utcnow, doc="""
+    Date/time when the token was created.
+    """)
+
+    def __str__(self):
+        return self.description or ""
