@@ -24,6 +24,8 @@
 Data Models for Vendors
 """
 
+import warnings
+
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.orm import relationship
@@ -92,11 +94,17 @@ class Vendor(Base):
         self.phones.append(phone)
 
     def get_email(self, type_='Info'):
+        warnings.warn("vendor.get_email() is deprecated; please "
+                      "use app.get_contact_email(vendor) instead",
+                      DeprecationWarning, stacklevel=2)
         for email in self.emails:
             if email.type == type_:
                 return email
 
     def get_email_address(self, *args, **kwargs):
+        warnings.warn("vendor.get_email_address() is deprecated; please "
+                      "use app.get_contact_email_address(vendor) instead",
+                      DeprecationWarning, stacklevel=2)
         email = self.get_email(*args, **kwargs)
         if email:
             return email.address
