@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Data Models for Work Orders
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import sqlalchemy as sa
 from sqlalchemy import orm
 
@@ -57,6 +55,7 @@ class WorkOrder(Base):
         """,
         backref=orm.backref(
             'workorders',
+            cascade_backrefs=False,
             doc="""
             Sequence of all work orders for this customer.
             """))
@@ -131,7 +130,8 @@ class WorkOrderEvent(Base):
         backref=orm.backref(
             'events',
             order_by='WorkOrderEvent.occurred',
-            cascade='all, delete-orphan'))
+            cascade='all, delete-orphan',
+            cascade_backrefs=False))
 
     type_code = sa.Column(sa.Integer, nullable=False, doc="""
     Code specifying the type of event this is.
