@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2023 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -30,9 +30,7 @@ import socket
 from traceback import format_exception
 
 from rattail.mail import Email
-from rattail.util import load_object
-from rattail.core import Object
-from rattail.time import make_utc, localtime
+from rattail.util import simple_error
 
 
 class ProblemReportEmail(Email):
@@ -152,7 +150,8 @@ class new_email_requested(Email):
     default_subject = "Email Update Request"
 
     def sample_data(self, request):
-        model = request.rattail_config.get_model()
+        app = request.rattail_config.get_app()
+        model = app.model
         customer = model.Customer(name="Fred Flintstone")
         return {
             'user': request.user,
@@ -171,7 +170,8 @@ class new_phone_requested(Email):
     default_subject = "Phone Update Request"
 
     def sample_data(self, request):
-        model = request.rattail_config.get_model()
+        app = request.rattail_config.get_app()
+        model = app.model
         customer = model.Customer(name="Fred Flintstone")
         return {
             'user': request.user,
@@ -182,6 +182,19 @@ class new_phone_requested(Email):
         }
 
 
+class pos_feedback(Email):
+    """
+    Sent when a user submits feedback from the POS
+    """
+    default_subject = "Feedback from POS"
+
+    def sample_data(self, request):
+        return {
+            'user_name': "Fred Flintstone",
+            'message': "Hey there,\n\njust wondered what the heck was going on with this POS?  It's crap.\n\nFred",
+        }
+
+
 class postfix_summary(Email):
     """
     Sends a summary of Postfix mail activity.
@@ -203,7 +216,8 @@ class ImporterEmail(Email):
     handler_spec = None
 
     def get_handler(self, config):
-        return load_object(self.handler_spec)(config)
+        app = config.get_app()
+        return app.load_object(self.handler_spec)(config)
 
     def get_default_subject(self, **data):
         host_title = data.get('host_title')
@@ -217,8 +231,9 @@ class ImporterEmail(Email):
         return "Changes for {} -> {}".format(host_title, local_title)
 
     def sample_data(self, request):
+        app = request.rattail_config.get_app()
         handler = self.get_handler(request.rattail_config)
-        obj = Object()
+        obj = app.make_object()
         local_data = {
             'foo': 42,
             'bar': True,
@@ -305,6 +320,37 @@ class rattail_problems_mailmon_misses(ProblemReportEmail):
         }
 
 
+class rattail_problems_pending_products(ProblemReportEmail):
+    """
+    Shows a list of pending products, if any are present.
+    """
+    default_subject = "Pending products"
+    abstract = False
+
+    def sample_data(self, request):
+        model = self.model
+
+        key = '074305001321'
+        pending = model.PendingProduct(item_id=key,
+                                       scancode=key,
+                                       upc=self.app.make_gpc(key),
+                                       brand_name="Bragg's",
+                                       description="Apple Cider Vinegar",
+                                       size="32oz",
+                                       status_code=self.enum.PENDING_PRODUCT_STATUS_PENDING)
+
+        url = self.config.base_url()
+        if url:
+            url = f'{url}/products/pending/'
+
+        return {
+            'problems': [pending],
+            'products_handler': self.app.get_products_handler(),
+            'enum': self.enum,
+            'url': url,
+        }
+
+
 class rattail_problems_stale_inventory_batch(ProblemReportEmail):
     """
     Nightly check for "stale" inventory batches, i.e. those created
@@ -314,7 +360,8 @@ class rattail_problems_stale_inventory_batch(ProblemReportEmail):
     abstract = False
 
     def sample_data(self, request):
-        model = self.config.get_model()
+        app = request.rattail_config.get_app()
+        model = app.model
         person = model.Person(display_name="Fred Flintstone")
         user = model.User(username='fred', person=person)
         batch = model.InventoryBatch(id=42, created=self.app.localtime(),
@@ -395,6 +442,26 @@ class trainwreck_problems_missing_dbs(ProblemReportEmail):
         }
 
 
+class uncaught_exception(Email):
+    """
+    Sent when an error happens which was not handled properly by the app.
+    This is more (only?) for GUI apps and not the web apps.
+    """
+    default_subject = "Uncaught Exception"
+
+    def sample_data(self, request):
+        try:
+            raise RuntimeError("Fake error for preview")
+        except:
+            exc_type, exc, traceback = sys.exc_info()
+
+        return {
+            'extra_context': {'foo': 'bar'},
+            'error': simple_error(exc),
+            'traceback': ''.join(format_exception(exc_type, exc, traceback)).strip(),
+        }
+
+
 class upgrade_failure(Email):
     """
     Sent when an app upgrade is attempted, but ultimately failed.
@@ -402,10 +469,11 @@ class upgrade_failure(Email):
     default_subject = "Upgrade failure for ${system_title}"
 
     def sample_data(self, request):
-        upgrade = Object(
+        app = request.rattail_config.get_app()
+        upgrade = app.make_object(
             description="upgrade to the latest!",
             notes="nothing special",
-            executed=make_utc(),
+            executed=app.make_utc(),
             executed_by="Fred Flintstone",
             exit_code=42,
         )
@@ -423,10 +491,11 @@ class upgrade_success(Email):
     default_subject = "Upgrade success for ${system_title}"
 
     def sample_data(self, request):
-        upgrade = Object(
+        app = request.rattail_config.get_app()
+        upgrade = app.make_object(
             description="upgrade to the latest!",
             notes="nothing special",
-            executed=make_utc(),
+            executed=app.make_utc(),
             executed_by="Fred Flintstone",
             exit_code=0,
         )
