@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2023 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,8 @@
 Excel utilities
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 
-import six
 import xlrd
 from xlrd.xldate import xldate_as_tuple
 
@@ -183,7 +180,7 @@ class ExcelReaderXLSX(object):
     # the older xlrd-based reader above.  maybe should just deprecate
     # and/or remove it though
     def parse_date(self, value, fmt=None):
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             if not value:
                 return
             return datetime.datetime.strptime(value, fmt or self.datefmt).date()
@@ -318,7 +315,7 @@ class ExcelWriter(object):
         cached = []
 
         def cache(row, i):
-            cached.append([len(six.text_type(value))
+            cached.append([len(str(value))
                            for value in row])
 
         progress_loop(cache, list(self.sheet.values), progress,
