@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,13 +24,12 @@
 CSV -> Rattail data import
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 import csv
 import datetime
+import decimal
+from collections import OrderedDict
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy_utils.functions import get_primary_keys
@@ -39,11 +38,9 @@ from rattail import importing, csvutil
 from rattail.importing.handlers import FromFileHandler
 from rattail.importing.files import FromFile
 from rattail.db.util import make_topo_sortkey
-from rattail.util import OrderedDict
-from rattail.config import parse_bool
 
 
-class FromCSVToSQLAlchemyMixin(object):
+class FromCSVToSQLAlchemyMixin:
 
     host_key = 'csv'
     generic_host_title = "CSV"
@@ -80,8 +77,6 @@ class FromCSVToSQLAlchemyMixin(object):
         fields = list(mapper.columns.keys())
         pkeys = get_primary_keys(cls)
         name = '{}Importer'.format(name)
-        if six.PY2:
-            name = name.encode('utf_8')
         return type(name, (FromCSV, self.ToParent), {
             'model_class': cls,
             'supported_fields': fields,
@@ -125,8 +120,17 @@ class FromCSVToSQLAlchemyMixin(object):
                 else:
                     coercers[field] = self.coerce_float
 
+            # Decimal
+            elif isinstance(attr.type, sa.Numeric):
+                if column.nullable:
+                    coercers[field] = self.coerce_decimal_nullable
+                else:
+                    coercers[field] = self.coerce_decimal
+
             # DateTime
-            elif isinstance(attr.type, sa.DateTime):
+            elif (isinstance(attr.type, sa.DateTime)
+                  or (hasattr(attr.type, 'impl')
+                      and isinstance(attr.type.impl, sa.DateTime))):
                 if column.nullable:
                     coercers[field] = self.coerce_datetime_nullable
                 else:
@@ -138,7 +142,7 @@ class FromCSVToSQLAlchemyMixin(object):
         return coercers
 
     def coerce_boolean(self, value):
-        return parse_bool(value)
+        return self.config.parse_bool(value)
 
     def coerce_boolean_nullable(self, value):
         if value == '':
@@ -165,10 +169,24 @@ class FromCSVToSQLAlchemyMixin(object):
             return None
         return self.coerce_float(value)
 
+    def coerce_decimal(self, value):
+        if value == '':
+            return None
+        return decimal.Decimal(value)
+
+    def coerce_decimal_nullable(self, value):
+        if value == '':
+            return None
+        return self.coerce_decimal(value)
+
     def coerce_datetime(self, value):
         if value == '':
             return
-        return datetime.datetime.strptime(value, '%Y-%m-%d %H:%M:%S')
+
+        try:
+            return datetime.datetime.strptime(value, '%Y-%m-%d %H:%M:%S')
+        except ValueError:
+            return datetime.datetime.strptime(value, '%Y-%m-%d %H:%M:%S.%f')
 
     def coerce_datetime_nullable(self, value):
         if value == '':
@@ -197,7 +215,7 @@ class FromCSVToRattail(FromCSVToSQLAlchemyMixin, FromFileHandler, importing.ToRa
 
     def get_model(self):
         if self.config:
-            return self.config.get_model()
+            return self.app.model
 
         from rattail.db import model
         return model
@@ -213,12 +231,8 @@ class FromCSV(FromFile):
         return '{}.csv'.format(self.model_name)
 
     def open_input_file(self):
-        if six.PY2:
-            self.input_file = open(self.input_file_path, 'rb')
-            self.input_reader = csvutil.UnicodeDictReader(self.input_file, encoding=self.csv_encoding)
-        else: # PY3
-            self.input_file = open(self.input_file_path, 'rt', encoding=self.csv_encoding)
-            self.input_reader = csv.DictReader(self.input_file)
+        self.input_file = open(self.input_file_path, 'rt', encoding=self.csv_encoding)
+        self.input_reader = csv.DictReader(self.input_file)
 
     def close_input_file(self):
         self.input_file.close()
