@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,24 +24,20 @@
 Rattail Data Exporters
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 import csv
+from collections import OrderedDict
 
-import six
 from sqlalchemy import orm
 from sqlalchemy_utils.functions import get_primary_keys
 
-from rattail import csvutil
-from rattail.util import OrderedDict
 from rattail.db.util import make_topo_sortkey
 from rattail.importing import Importer
 from rattail.importing.rattail import FromRattailHandler, FromRattail
 from rattail.importing.handlers import ToCSVHandler
 
 
-class FromSQLAlchemyToCSVMixin(object):
+class FromSQLAlchemyToCSVMixin:
 
     # subclass must define this
     FromParent = None
@@ -81,8 +77,6 @@ class FromSQLAlchemyToCSVMixin(object):
         fields = list(mapper.columns.keys())
         pkeys = get_primary_keys(cls)
         name = '{}Importer'.format(name)
-        if six.PY2:
-            name = name.encode('utf_8')
         return type(name, (self.FromParent, ToCSV), {
             'model_class': cls,
             'supported_fields': fields,
@@ -105,7 +99,7 @@ class FromRattailToCSV(FromSQLAlchemyToCSVMixin, FromRattailHandler, ToCSVHandle
 
     def get_model(self):
         if self.config:
-            return self.config.get_model()
+            return self.app.model
 
         from rattail.db import model
         return model
@@ -118,7 +112,7 @@ class ToFile(Importer):
     empty_local_data = True
 
     def setup(self):
-        super(ToFile, self).setup()
+        super().setup()
 
         if not hasattr(self, 'output_file_path'):
             filename = self.get_output_filename()
@@ -127,7 +121,7 @@ class ToFile(Importer):
             self.open_output_file()
 
     def teardown(self):
-        super(ToFile, self).teardown()
+        super().teardown()
 
         if not self.dry_run:
             self.close_output_file()
@@ -170,15 +164,16 @@ class ToCSV(ToFile):
     """
     Base class for importers which target CSV file on the local side.
     """
+    allow_delete = False
     empty_local_data = True
 
     def open_output_file(self):
-        if six.PY2:
-            self.output_file = open(self.output_file_path, 'wb')
-            self.output_writer = csvutil.UnicodeDictWriter(self.output_file, self.fields, encoding='utf_8')
-        else: # PY3
-            self.output_file = open(self.output_file_path, 'wt', encoding='utf_8')
-            self.output_writer = csv.DictWriter(self.output_file, self.fields)
+        self.output_file = open(self.output_file_path, 'wt',
+                                encoding='utf_8')
+
+        self.output_writer = csv.DictWriter(self.output_file, self.fields,
+                                            quoting=csv.QUOTE_NONNUMERIC)
+
         self.write_output_header()
 
     def write_output_header(self):
@@ -207,8 +202,11 @@ class ToCSV(ToFile):
             if value is None:
                 value = ''
 
+            elif isinstance(value, (int, float)):
+                pass
+
             else:
-                value = six.text_type(value)
+                value = str(value)
 
             coerced[field] = value
         return coerced
