@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,17 +24,15 @@
 IFPS -> Rattail data import
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 import logging
+from collections import OrderedDict
 
 import sqlalchemy as sa
 
 from rattail import importing
 from rattail.importing.handlers import FromFileHandler
 from rattail.importing.files import FromExcelFile
-from rattail.util import OrderedDict
 from rattail.time import localtime, make_utc
 from rattail.db.util import maxlen
 
