@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2023 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -25,14 +25,13 @@ Rattail -> Rattail data import
 """
 
 import logging
+from collections import OrderedDict
 
 import sqlalchemy as sa
 
-from rattail.db import Session
 from rattail.importing import model
 from rattail.importing.handlers import FromSQLAlchemyHandler, ToSQLAlchemyHandler
 from rattail.importing.sqlalchemy import FromSQLAlchemySameToSame
-from rattail.util import OrderedDict
 
 
 log = logging.getLogger(__name__)
@@ -50,7 +49,7 @@ class FromRattailHandler(FromSQLAlchemyHandler):
         return self.config.app_title(default="Rattail")
 
     def make_host_session(self):
-        return Session()
+        return self.app.make_session()
 
 
 class ToRattailHandler(ToSQLAlchemyHandler):
@@ -68,14 +67,14 @@ class ToRattailHandler(ToSQLAlchemyHandler):
         kwargs = {}
         if hasattr(self, 'runas_user'):
             kwargs['continuum_user'] = self.runas_user
-        return Session(**kwargs)
+        return self.app.make_session(**kwargs)
 
     def begin_local_transaction(self):
         self.session = self.make_session()
 
         # load "runas user" into current session
         if hasattr(self, 'runas_user') and self.runas_user:
-            dbmodel = self.config.get_model()
+            dbmodel = self.app.model
             runas_user = self.session.get(dbmodel.User, self.runas_user.uuid)
             if not runas_user:
                 log.info("runas_user does not exist in target session: %s",
@@ -119,12 +118,16 @@ class FromRattailToRattailBase(object):
         importers['Customer'] = CustomerImporter
         importers['CustomerGroup'] = CustomerGroupImporter
         importers['CustomerGroupAssignment'] = CustomerGroupAssignmentImporter
+        importers['CustomerShopper'] = CustomerShopperImporter
+        importers['CustomerShopperHistory'] = CustomerShopperHistoryImporter
         importers['CustomerPerson'] = CustomerPersonImporter
         importers['CustomerEmailAddress'] = CustomerEmailAddressImporter
         importers['CustomerPhoneNumber'] = CustomerPhoneNumberImporter
         importers['Member'] = MemberImporter
         importers['MemberEmailAddress'] = MemberEmailAddressImporter
         importers['MemberPhoneNumber'] = MemberPhoneNumberImporter
+        importers['MemberEquityPayment'] = MemberEquityPaymentImporter
+        importers['Tender'] = TenderImporter
         importers['Vendor'] = VendorImporter
         importers['VendorEmailAddress'] = VendorEmailAddressImporter
         importers['VendorPhoneNumber'] = VendorPhoneNumberImporter
@@ -191,7 +194,7 @@ class FromRattailToRattailImport(FromRattailToRattailBase, FromRattailHandler, T
         return self.config.node_title(default="Rattail (local)")
 
     def make_host_session(self):
-        return Session(bind=self.config.rattail_engines[self.dbkey])
+        return self.app.make_session(bind=self.config.rattail_engines[self.dbkey])
 
 
 class FromRattailToRattailExport(FromRattailToRattailBase, FromRattailHandler, ToRattailHandler):
@@ -215,7 +218,7 @@ class FromRattailToRattailExport(FromRattailToRattailBase, FromRattailHandler, T
         return "{} ({})".format(self.config.app_title(default="Rattail"), self.dbkey)
 
     def make_session(self):
-        return Session(bind=self.config.rattail_engines[self.dbkey])
+        return self.app.make_session(bind=self.config.rattail_engines[self.dbkey])
 
 
 class FromRattail(FromSQLAlchemySameToSame):
@@ -235,7 +238,7 @@ class GlobalPersonImporter(FromRattail, model.GlobalPersonImporter):
     """
 
     def query(self):
-        query = super(GlobalPersonImporter, self).query()
+        query = super().query()
 
         # never include "local only" people
         query = query.filter(sa.or_(
@@ -250,7 +253,7 @@ class GlobalPersonImporter(FromRattail, model.GlobalPersonImporter):
         if person.local_only:
             return
 
-        data = super(GlobalPersonImporter, self).normalize_host_object(person)
+        data = super().normalize_host_object(person)
         return data
 
 
@@ -279,7 +282,7 @@ class GlobalRoleImporter(RoleImporter):
 
     @property
     def supported_fields(self):
-        fields = list(super(GlobalRoleImporter, self).supported_fields)
+        fields = list(super().supported_fields)
         fields.extend([
             'permissions',
             'users',
@@ -293,7 +296,7 @@ class GlobalRoleImporter(RoleImporter):
         """
         Return the query to be used when caching "local" data.
         """
-        query = super(GlobalRoleImporter, self).cache_query()
+        query = super().cache_query()
         model = self.model
 
         # only want roles which are *meant* to be synced
@@ -302,7 +305,7 @@ class GlobalRoleImporter(RoleImporter):
         return query
 
     def query(self):
-        query = super(GlobalRoleImporter, self).query()
+        query = super().query()
         model = self.model
 
         # only want roles which are *meant* to be synced
@@ -319,7 +322,7 @@ class GlobalRoleImporter(RoleImporter):
         if not role.sync_me:
             return
 
-        data = super(GlobalRoleImporter, self).normalize_local_object(role)
+        data = super().normalize_local_object(role)
         if data:
 
             # users
@@ -336,9 +339,7 @@ class GlobalRoleImporter(RoleImporter):
             return data
 
     def update_object(self, role, host_data, local_data=None, **kwargs):
-        role = super(GlobalRoleImporter, self).update_object(role, host_data,
-                                                             local_data=local_data,
-                                                             **kwargs)
+        role = super().update_object(role, host_data, local_data=local_data, **kwargs)
         model = self.model
 
         # users
@@ -406,7 +407,7 @@ class GlobalUserImporter(FromRattail, model.GlobalUserImporter):
     """
 
     def query(self):
-        query = super(GlobalUserImporter, self).query()
+        query = super().query()
 
         # never include "local only" users
         query = query.filter(sa.or_(
@@ -421,7 +422,7 @@ class GlobalUserImporter(FromRattail, model.GlobalUserImporter):
         if user.local_only:
             return
 
-        data = super(GlobalUserImporter, self).normalize_host_object(user)
+        data = super().normalize_host_object(user)
         return data
 
 
@@ -429,12 +430,12 @@ class AdminUserImporter(FromRattail, model.AdminUserImporter):
 
     @property
     def supported_fields(self):
-        return super(AdminUserImporter, self).supported_fields + [
+        return super().supported_fields + [
             'admin',
         ]
 
     def normalize_host_object(self, user):
-        data = super(AdminUserImporter, self).normalize_local_object(user) # sic
+        data = super().normalize_local_object(user) # sic
         if 'admin' in self.fields: # TODO: do we really need this, after the above?
             data['admin'] = self.admin_uuid in [r.role_uuid for r in user._roles]
         return data
@@ -482,6 +483,12 @@ class CustomerGroupImporter(FromRattail, model.CustomerGroupImporter):
 class CustomerGroupAssignmentImporter(FromRattail, model.CustomerGroupAssignmentImporter):
     pass
 
+class CustomerShopperImporter(FromRattail, model.CustomerShopperImporter):
+    pass
+
+class CustomerShopperHistoryImporter(FromRattail, model.CustomerShopperHistoryImporter):
+    pass
+
 class CustomerPersonImporter(FromRattail, model.CustomerPersonImporter):
     pass
 
@@ -500,6 +507,12 @@ class MemberEmailAddressImporter(FromRattail, model.MemberEmailAddressImporter):
 class MemberPhoneNumberImporter(FromRattail, model.MemberPhoneNumberImporter):
     pass
 
+class MemberEquityPaymentImporter(FromRattail, model.MemberEquityPaymentImporter):
+    pass
+
+class TenderImporter(FromRattail, model.TenderImporter):
+    pass
+
 class VendorImporter(FromRattail, model.VendorImporter):
     pass
 
@@ -562,7 +575,7 @@ class ProductWithPriceImporter(FromRattail, model.ProductImporter):
     ]
 
     def query(self):
-        query = super(ProductWithPriceImporter, self).query()
+        query = super().query()
 
         # make sure potential unit items (i.e. rows with NULL unit_uuid) come
         # first, so they will be created before pack items reference them
@@ -593,7 +606,7 @@ class ProductImporter(ProductWithPriceImporter):
 
     @property
     def simple_fields(self):
-        fields = super(ProductImporter, self).simple_fields
+        fields = super().simple_fields
         # NOTE: it seems we can't consider these "simple" due to the
         # self-referencing foreign key situation.  an importer can still
         # "support" these fields, but they're excluded from the simple set for
@@ -641,7 +654,7 @@ class ProductImageImporter(FromRattail, model.ProductImageImporter):
 class LabelProfileImporter(FromRattail, model.LabelProfileImporter):
 
     def query(self):
-        query = super(LabelProfileImporter, self).query()
+        query = super().query()
 
         if not self.config.getbool('rattail', 'labels.sync_all_profiles', default=False):
             # only fetch labels from host which are marked as "sync me"
