@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,7 +24,7 @@
 Rattail -> Rattail "versions" data import
 """
 
-from __future__ import unicode_literals, absolute_import
+from collections import OrderedDict
 
 import sqlalchemy_continuum as continuum
 
@@ -32,7 +32,6 @@ from rattail.db import model
 from rattail.db.continuum import versioning_manager
 from rattail.importing.rattail import FromRattailHandler, ToRattailHandler, FromRattail
 from rattail.importing.model import ToRattail
-from rattail.util import OrderedDict
 
 
 class FromRattailToRattailVersions(FromRattailHandler, ToRattailHandler):
@@ -66,13 +65,17 @@ class FromRattailToRattailVersions(FromRattailHandler, ToRattailHandler):
         importers['CustomerPhoneNumber'] = CustomerPhoneNumberImporter
         importers['CustomerEmailAddress'] = CustomerEmailAddressImporter
         importers['CustomerMailingAddress'] = CustomerMailingAddressImporter
+        importers['CustomerShopper'] = CustomerShopperImporter
+        importers['CustomerShopperHistory'] = CustomerShopperHistoryImporter
         importers['CustomerPerson'] = CustomerPersonImporter
         importers['CustomerGroup'] = CustomerGroupImporter
         importers['CustomerGroupAssignment'] = CustomerGroupAssignmentImporter
+        importers['MembershipType'] = MembershipTypeImporter
         importers['Member'] = MemberImporter
         importers['MemberPhoneNumber'] = MemberPhoneNumberImporter
         importers['MemberEmailAddress'] = MemberEmailAddressImporter
         importers['MemberMailingAddress'] = MemberMailingAddressImporter
+        importers['MemberEquityPayment'] = MemberEquityPaymentImporter
         importers['Employee'] = EmployeeImporter
         importers['EmployeePhoneNumber'] = EmployeePhoneNumberImporter
         importers['EmployeeEmailAddress'] = EmployeeEmailAddressImporter
@@ -80,6 +83,7 @@ class FromRattailToRattailVersions(FromRattailHandler, ToRattailHandler):
         importers['EmployeeDepartment'] = EmployeeDepartmentImporter
         importers['EmployeeHistory'] = EmployeeHistoryImporter
         importers['WorkedShift'] = WorkedShiftImporter
+        importers['Tender'] = TenderImporter
         importers['Vendor'] = VendorImporter
         importers['VendorPhoneNumber'] = VendorPhoneNumberImporter
         importers['VendorEmailAddress'] = VendorEmailAddressImporter
@@ -165,6 +169,23 @@ class VersionImporter(FromRattail, ToRattail):
         last_version.end_transaction_id = self.transaction.id
         return self.make_version(host_data, continuum.Operation.UPDATE)
     
+    def delete_object(self, obj):
+
+        # TODO: apparently for the longest time, this importer was
+        # *deleting* old version records, instead of *adding* a new
+        # "DELETE" record.  we now do the latter (below) but it
+        # remains to be seen if that is always the correct
+        # behavior..we'll see what breaks i guess..
+
+        # nb. the `obj` here is a version record
+        obj.end_transaction_id = self.transaction.id
+
+        # nb. must fake the host data, not sure it could matter?
+        host_data = self.normalize_local_object(obj)
+
+        # add new "delete" version record
+        return self.make_version(host_data, continuum.Operation.DELETE)
+
 
 class PersonImporter(VersionImporter):
     host_model_class = model.Person
@@ -214,6 +235,12 @@ class CustomerEmailAddressImporter(VersionImporter):
 class CustomerMailingAddressImporter(VersionImporter):
     host_model_class = model.CustomerMailingAddress
 
+class CustomerShopperImporter(VersionImporter):
+    host_model_class = model.CustomerShopper
+
+class CustomerShopperHistoryImporter(VersionImporter):
+    host_model_class = model.CustomerShopperHistory
+
 class CustomerPersonImporter(VersionImporter):
     host_model_class = model.CustomerPerson
 
@@ -223,6 +250,9 @@ class CustomerGroupImporter(VersionImporter):
 class CustomerGroupAssignmentImporter(VersionImporter):
     host_model_class = model.CustomerGroupAssignment
 
+class MembershipTypeImporter(VersionImporter):
+    host_model_class = model.MembershipType
+
 class MemberImporter(VersionImporter):
     host_model_class = model.Member
 
@@ -235,6 +265,9 @@ class MemberEmailAddressImporter(VersionImporter):
 class MemberMailingAddressImporter(VersionImporter):
     host_model_class = model.MemberMailingAddress
 
+class MemberEquityPaymentImporter(VersionImporter):
+    host_model_class = model.MemberEquityPayment
+
 class EmployeeImporter(VersionImporter):
     host_model_class = model.Employee
 
@@ -256,6 +289,9 @@ class EmployeeHistoryImporter(VersionImporter):
 class WorkedShiftImporter(VersionImporter):
     host_model_class = model.WorkedShift
 
+class TenderImporter(VersionImporter):
+    host_model_class = model.Tender
+
 class VendorImporter(VersionImporter):
     host_model_class = model.Vendor
 
