@@ -29,13 +29,13 @@ import os
 import os.path
 import socket
 import shutil
+from collections import OrderedDict
 
 from rattail.app import GenericHandler
 from rattail.core import Object
 from rattail.files import temp_path
 from rattail.exceptions import LabelPrintingError
 from rattail.time import localtime
-from rattail.util import OrderedDict
 
 
 class LabelHandler(GenericHandler):
@@ -43,6 +43,17 @@ class LabelHandler(GenericHandler):
     Base class and default implementation for label handlers.
     """
 
+    def get_label_profiles(self, session, visible=True, **kwargs):
+        """
+        Return the set of label profiles which are available for use
+        with actual product label printing.
+        """
+        model = self.model
+        return session.query(model.LabelProfile)\
+                      .filter(model.LabelProfile.visible == visible)\
+                      .order_by(model.LabelProfile.ordinal)\
+                      .all()
+
     def get_formatter(self, profile, ignore_errors=False):
         """
         Return the label formatter for the given profile.
