@@ -24,17 +24,14 @@
 Luigi utilities
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 import logging
 import subprocess
 import sys
 import warnings
+from xmlrpc.client import ProtocolError
 
 import sqlalchemy as sa
-import six
-from six.moves.xmlrpc_client import ProtocolError
 
 from rattail.app import GenericHandler
 from rattail.util import shlex_join
@@ -100,13 +97,13 @@ class LuigiHandler(GenericHandler):
             if keys:
                 warnings.warn("setting is deprecated: [rattail.luigi] overnight_tasks; "
                               "please use [rattail.luigi] overnight.tasks instead",
-                              DeprecationWarning)
+                              DeprecationWarning, stacklevel=2)
 
         for key in keys:
             if key.startswith('overnight-'):
                 key = key[len('overnight-'):]
                 warnings.warn("overnight task keys use deprecated 'overnight-' prefix",
-                              DeprecationWarning)
+                              DeprecationWarning, stacklevel=2)
 
             lastrun = self.get_overnight_task_setting(key, 'lastrun')
             lastrun = self.app.parse_utctime(lastrun, local=True)
@@ -136,7 +133,7 @@ class LuigiHandler(GenericHandler):
             if value is not None:
                 warnings.warn("[rattail.luigi] overnight.overnight-* settings are deprecated; "
                               "please use [rattail.luigi] overnight.task.* instead",
-                              DeprecationWarning)
+                              DeprecationWarning, stacklevel=2)
         return value
 
     def get_overnight_task(self, key, **kwargs):
@@ -188,7 +185,14 @@ class LuigiHandler(GenericHandler):
            but do not actually run it.
         """
         appdir = self.config.appdir()
-        env = {'PYTHONPATH': appdir}
+
+        # must preserve existing environ, but also add some things to it
+        env = dict(os.environ)
+        if 'PYTHONPATH' in env:
+            env['PYTHONPATH'] += os.pathsep + appdir
+        else:
+            env['PYTHONPATH'] = appdir
+
         if keep_config:
             env['RATTAIL_CONFIG_FILES'] = os.pathsep.join(self.config.files_read)
         else:
@@ -258,6 +262,18 @@ class LuigiHandler(GenericHandler):
             log.debug("dry-run mode, so aborting")
             return
 
+        # TODO: most overnight tasks can run okay, but occasionally we
+        # need an overnight task to rebuild the current app DB - i.e.
+        # drop the DB and re-clone from production.  in these cases we
+        # cannot afford to have lingering connections to the current
+        # DB or else dropping it may fail.  so our fix for now, is to
+        # foribly recreate the connection pool for all overnight task
+        # runs.  would be nice to be more selective but this seems to
+        # work okay for now...
+        pool = self.config.rattail_engine.pool
+        pool.dispose()
+        self.config.rattail_engine.pool = pool.recreate()
+
         # run command in subprocess
         curdir = os.getcwd()
         try:
@@ -284,7 +300,7 @@ class LuigiHandler(GenericHandler):
     def record_overnight_last_date(self, task, date, session=None, **kwargs):
         name = 'rattail.luigi.overnight.task.{}.last_date'.format(task['key'])
         with self.app.short_session(session=session, commit=True) as s:
-            self.app.save_setting(s, name, six.text_type(date))
+            self.app.save_setting(s, name, str(date))
 
     def get_all_backfill_tasks(self, **kwargs):
         tasks = []
@@ -297,13 +313,13 @@ class LuigiHandler(GenericHandler):
             if keys:
                 warnings.warn("setting is deprecated: [rattail.luigi] backfill_tasks; "
                               "please use [rattail.luigi] backfill.tasks instead",
-                              DeprecationWarning)
+                              DeprecationWarning, stacklevel=2)
 
         for key in keys:
             if key.startswith('backfill-'):
                 key = key[len('backfill-'):]
                 warnings.warn("backfill task keys use deprecated 'backfill-' prefix",
-                              DeprecationWarning)
+                              DeprecationWarning, stacklevel=2)
 
             lastrun = self.get_backfill_task_setting(key, 'lastrun')
             lastrun = self.app.parse_utctime(lastrun, local=True)
@@ -337,7 +353,7 @@ class LuigiHandler(GenericHandler):
             if value is not None:
                 warnings.warn("[rattail.luigi] backfill.* settings are deprecated; "
                               "please use [rattail.luigi] backfill.task.* instead",
-                              DeprecationWarning)
+                              DeprecationWarning, stacklevel=2)
         return value
 
     def get_backfill_task(self, key, **kwargs):
@@ -474,7 +490,7 @@ class LuigiHandler(GenericHandler):
     def record_backfill_last_date(self, task, date, session=None, **kwargs):
         name = 'rattail.luigi.backfill.task.{}.last_date'.format(task['key'])
         with self.app.short_session(session=session, commit=True) as s:
-            self.app.save_setting(s, name, six.text_type(date))
+            self.app.save_setting(s, name, str(date))
 
     def purge_overnight_settings(self, session):
         model = self.model
