@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2023 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,6 +24,7 @@
 Email Framework
 """
 
+import importlib
 import os
 import smtplib
 import logging
@@ -34,8 +35,6 @@ from email.mime.multipart import MIMEMultipart
 from email.mime.application import MIMEApplication
 from email.mime.text import MIMEText
 
-import six
-
 from mako.template import Template
 from mako.lookup import TemplateLookup
 from mako.exceptions import TopLevelLookupException
@@ -43,8 +42,8 @@ from mako.exceptions import TopLevelLookupException
 from rattail import exceptions
 from rattail.core import UNSPECIFIED
 from rattail.files import resource_path
-from rattail.util import import_module_path, load_entry_points
-from rattail.time import localtime, make_utc
+from rattail.util import load_entry_points
+from rattail.time import localtime
 
 
 # NOTE: this bit of magic was stolen from Django
@@ -94,7 +93,7 @@ class EmailHandler(object):
         except ImportError:
             pass
         else:
-            self.model = self.config.get_model()
+            self.model = self.app.model
 
     def use_entry_points(self):
         """
@@ -103,7 +102,7 @@ class EmailHandler(object):
         the (legacy) ``[rattail.mail] emails`` config setting.
         """
         return self.config.getbool('rattail.mail', 'emails.use_entry_points',
-                                   default=False)
+                                   default=True)
 
     def should_record_attempts(self):
         """
@@ -139,11 +138,18 @@ class EmailHandler(object):
         all_modules = load_entry_points('rattail.emails').values()
 
         # but maybe the app config says only to use certain modules
-        app_modules = self.config.getlist('rattail.mail', 'emails')
+        app_modules = self.config.getlist('rattail.mail', 'emails.modules')
+        if not app_modules:
+            app_modules = self.config.getlist('rattail.mail', 'emails',
+                                              ignore_ambiguous=True)
+            if app_modules:
+                warnings.warn(f"URGENT: instead of 'rattail.mail.emails', "
+                              f"you should set 'rattail.mail.emails.modules'",
+                              DeprecationWarning, stacklevel=2)
 
         # figure out which modules we should actually use
         if app_modules:
-            modules = [import_module_path(m)
+            modules = [importlib.import_module(m)
                        for m in app_modules]
         else:
             modules = all_modules
@@ -188,7 +194,7 @@ class EmailHandler(object):
                           DeprecationWarning, stacklevel=2)
 
         for module in self.config.getlist('rattail.mail', 'emails', default=['rattail.emails']):
-            module = import_module_path(module)
+            module = importlib.import_module(module)
             for email in self.get_emails_from_module(module):
                 yield email
 
@@ -267,7 +273,7 @@ class EmailHandler(object):
         attempt.cc = msg.get_all('Cc')
         attempt.bcc = msg.get_all('Bcc')
         attempt.subject = msg['Subject']
-        attempt.sent = make_utc()
+        attempt.sent = self.app.make_utc()
         attempt.status_code = self.enum.EMAIL_ATTEMPT_CREATED
         session.add(attempt)
 
@@ -307,6 +313,7 @@ class EmailHandler(object):
         context['rattail_config'] = self.config
         context['app'] = self.app
         context['app_title'] = self.config.app_title(default="Rattail")
+        # TODO: deprecate / remove this
         context['localtime'] = localtime
         return context
 
@@ -410,7 +417,7 @@ class Email(object):
         except ImportError:
             pass
         else:
-            self.model = self.config.get_model()
+            self.model = self.app.model
 
         if key:
             self.key = key
@@ -424,10 +431,14 @@ class Email(object):
         if default_subject:
             self.default_subject = default_subject
 
-        templates = config.getlist('rattail.mail', 'templates')
+        templates = config.getlist('rattail.mail', 'templates',
+                                   default=['rattail:templates/mail'])
         if templates:
             templates = [resource_path(p) for p in templates]
-        self.templates = TemplateLookup(directories=templates)
+        self.txt_templates = TemplateLookup(directories=templates)
+        self.html_templates = TemplateLookup(directories=templates,
+                                             # nb. this escapes HTML special chars
+                                             default_filters=['h'])
 
     def obtain_sample_data(self, request):
         """
@@ -532,9 +543,9 @@ class Email(object):
         # TODO: not sure that's possible since we try node title above
         prefix = prefix or self.default_prefix
 
-        # force the [STAGE] prefix unless running in production
+        # force the [DEV] prefix unless running in production
         if magic and not self.config.production():
-            prefix = "[STAGE] {}".format(prefix)
+            prefix = "[DEV] {}".format(prefix)
 
         return prefix
 
@@ -593,12 +604,18 @@ class Email(object):
         Locate and return the Mako email template of the given type
         (e.g. 'html'), or ``None`` if no such template can be found.
         """
+        if type_ == 'txt':
+            templates = self.txt_templates
+        else:
+            assert type_ == 'html'
+            templates = self.html_templates
+
         try:
-            return self.templates.get_template('{0}.{1}.mako'.format(self.key, type_))
+            return templates.get_template(f'{self.key}.{type_}.mako')
         except TopLevelLookupException:
             if self.fallback_key:
                 try:
-                    return self.templates.get_template('{0}.{1}.mako'.format(self.fallback_key, type_))
+                    return templates.get_template(f'{self.fallback_key}.{type_}.mako')
                 except TopLevelLookupException:
                     pass
 
@@ -648,7 +665,7 @@ class Email(object):
         attachments = self.normalize_attachments(attachments)
 
         # TODO: provide more defaults?
-        data.setdefault('six', six)
+        data.setdefault('app', self.app)
 
         if txt_template and html_template:
 
