@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2023 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,7 +24,7 @@
 Mail Monitor Configuration
 """
 
-from rattail.config import ConfigProfile, parse_list
+from rattail.config import ConfigProfile
 from rattail.exceptions import ConfigurationError
 
 
@@ -98,14 +98,14 @@ def load_mailmon_profiles(config):
 
     # first load the accounts
     accounts = {}
-    for key in parse_list(account_keys):
+    for key in config.parse_list(account_keys):
         profile = MailMonitorAccountProfile(config, key,
                                             prefix='account.{}'.format(key))
         accounts[key] = profile
 
     # now load the monitor profiles
     monitored = {'__accounts__': accounts}
-    for key in parse_list(monitor_keys):
+    for key in config.parse_list(monitor_keys):
         profile = MailMonitorProfile(config, key)
 
         # only monitor this profile if it uses valid account
