@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2023 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -28,17 +28,94 @@ See also :doc:`rattail-manual:base/handlers/other/people`.
 
 import warnings
 
-import sqlalchemy as sa
+from wuttjamaican import people as base
 
-from rattail.app import GenericHandler, MergeMixin
-from rattail.time import make_utc
+from rattail.app import MergeMixin
 
 
-class PeopleHandler(GenericHandler, MergeMixin):
+class PeopleHandler(base.PeopleHandler, MergeMixin):
     """
     Base class and default implementation for people handlers.
     """
 
+    def get_person(self, obj, **kwargs):
+        """
+        Retrieve the Person related to the given object.
+
+        This is a rather fundamental method, in that it is called by
+        several other methods, both within this handler as well as
+        others.  There is even a shortcut to it, accessible via
+        :meth:`rattail.app.AppHandler.get_person()`.
+
+        Its purpose is to navigate relationships as needed, to get at
+        the "default" person associated with the object.  Depending on
+        how the app tracks relationships, this logic may need to vary.
+        """
+        model = self.model
+
+        if isinstance(obj, model.Person):
+            return obj
+
+        elif isinstance(obj, model.User):
+            if obj.person:
+                return obj.person
+
+        elif isinstance(obj, model.Employee):
+            return obj.person
+
+        elif isinstance(obj, model.Customer):
+            if obj.account_holder:
+                return obj.account_holder
+            if obj.shoppers:
+                return obj.shoppers[0].person
+            # legacy fallback
+            if obj.people:
+                return obj.people[0]
+
+        elif isinstance(obj, model.Member):
+            if obj.person:
+                return obj.person
+
+    def should_expose_quickie_search(self):
+        return self.config.getbool('rattail',
+                                   'people.expose_quickie_search',
+                                   default=False)
+
+    def should_use_preferred_first_name(self):
+        return self.config.getbool('rattail',
+                                   'people.use_preferred_first_name',
+                                   default=False)
+
+    def get_quickie_search_placeholder(self):
+        return self.app.get_customer_key_label()
+
+    def quickie_lookup(self, entry, session):
+        """
+        Attempt to locate a person based on the given entry.  By
+        default this will do a lookup based on the configured Customer
+        key field.  Override as needed.
+        """
+        from sqlalchemy import orm
+
+        model = self.model
+        field = self.app.get_customer_key_field()
+
+        # validate/coerce data type
+        # TOOD: this is a hack! should inspect field type etc.
+        if field == 'number':
+            if not entry.isdigit():
+                return
+            entry = int(entry)
+
+        try:
+            customer = session.query(model.Customer)\
+                              .filter(getattr(model.Customer, field) == entry)\
+                              .one()
+        except orm.exc.NoResultFound:
+            pass
+        else:
+            return self.app.get_person(customer)
+
     def normalize_full_name(self, first, last, **kwargs):
         """
         Normalize a "full" name based on the given first and last
@@ -60,6 +137,9 @@ class PeopleHandler(GenericHandler, MergeMixin):
 
         if 'first_name' in kwargs:
             person.first_name = kwargs.pop('first_name')
+        if self.should_use_preferred_first_name():
+            if 'preferred_first_name' in kwargs:
+                person.preferred_first_name = kwargs.pop('preferred_first_name')
         if 'middle_name' in kwargs:
             person.middle_name = kwargs.pop('middle_name')
         if 'last_name' in kwargs:
@@ -83,6 +163,7 @@ class PeopleHandler(GenericHandler, MergeMixin):
 
         :param person: Reference to a ``Person`` record.
         :param first: First name for the person.
+        :param preferred_first: Preferred first name for the person.
         :param middle: Middle name for the person.
         :param last: Last name for the person.
         :param full: Full (display) name for the person.
@@ -90,6 +171,10 @@ class PeopleHandler(GenericHandler, MergeMixin):
         if 'first' in kwargs:
             person.first_name = kwargs['first']
 
+        if self.should_use_preferred_first_name():
+            if 'preferred_first' in kwargs:
+                person.preferred_first_name = kwargs['preferred_first']
+
         if 'middle' in kwargs:
             person.middle_name = kwargs['middle']
 
@@ -342,12 +427,12 @@ class PeopleHandler(GenericHandler, MergeMixin):
         performing the merge is free to swap them around.
         """
         model = self.model
-        session = self.get_session(user)
+        session = self.app.get_session(user)
         merge = model.MergePeopleRequest()
         merge.removing_uuid = removing_uuid
         merge.keeping_uuid = keeping_uuid
         merge.requested_by = user
-        merge.requested = make_utc()
+        merge.requested = self.app.make_utc()
         session.add(merge)
         session.flush()
         self.notify_of_merge_request(merge)
@@ -357,7 +442,7 @@ class PeopleHandler(GenericHandler, MergeMixin):
         """
         Send an email alert regarding a new merge request.
         """
-        session = self.get_session(merge)
+        session = self.app.get_session(merge)
         model = self.model
 
         removing = session.get(model.Person, merge.removing_uuid)
@@ -392,6 +477,8 @@ class PeopleHandler(GenericHandler, MergeMixin):
             F('display_name'),
             F('usernames', additive=True),
             F('employee_uuid', coalesce=True),
+            F('customer_account_uuids', additive=True),
+            F('shopper_uuids', additive=True),
             F('member_uuids', additive=True),
         ]
 
@@ -408,6 +495,8 @@ class PeopleHandler(GenericHandler, MergeMixin):
             'usernames': [u.username for u in person.users],
             'employee_uuid': person.employee.uuid if person.employee else None,
             'member_uuids': [m.uuid for m in person.members],
+            'customer_account_uuids': [c.uuid for c in person.customer_accounts],
+            'shopper_uuids': [s.uuid for s in person.customer_shoppers],
         }
 
     def why_not_merge(self, removing, keeping, **kwargs):
@@ -428,7 +517,7 @@ class PeopleHandler(GenericHandler, MergeMixin):
     def perform_merge(self, removing, keeping, **kwargs):
 
         # merge per usual
-        super(PeopleHandler, self).perform_merge(removing, keeping, **kwargs)
+        super().perform_merge(removing, keeping, **kwargs)
 
         # if there were pending requests for this merge, declare them satisfied
         self.satisfy_merge_requests(removing, keeping, user=kwargs.get('user'))
@@ -436,7 +525,16 @@ class PeopleHandler(GenericHandler, MergeMixin):
     def merge_update_keeping_object(self, removing, keeping):
 
         # update per usual
-        super(PeopleHandler, self).merge_update_keeping_object(removing, keeping)
+        super().merge_update_keeping_object(removing, keeping)
+
+        # move CustomerShopper records to final Person
+        for shopper in list(removing.customer_shoppers):
+            shopper.person = keeping
+
+        # move Customer records to final Person
+        for customer in list(removing.customer_accounts):
+            removing.customer_accounts.remove(customer)
+            keeping.customer_accounts.append(customer)
 
         # move Member records to final Person
         for member in list(removing.members):
@@ -460,7 +558,9 @@ class PeopleHandler(GenericHandler, MergeMixin):
         """
         If there was a merge request(s) for this pair, mark it complete.
         """
-        session = self.get_session(keeping)
+        import sqlalchemy as sa
+
+        session = self.app.get_session(keeping)
         model = self.model
         merge_requests = session.query(model.MergePeopleRequest)\
                                 .filter(sa.or_(
@@ -475,7 +575,7 @@ class PeopleHandler(GenericHandler, MergeMixin):
             # set the record straight re: removing vs. keeping
             merge_request.removing_uuid = removing.uuid
             merge_request.keeping_uuid = keeping.uuid
-            merge_request.merged = make_utc()
+            merge_request.merged = self.app.make_utc()
             merge_request.merged_by = user
 
 def get_people_handler(config, **kwargs):
@@ -488,6 +588,6 @@ def get_people_handler(config, **kwargs):
     """
     warnings.warn("get_people_handler() function is deprecated, "
                   "please use app.get_people_handler() method instead",
-                  DeprecationWarning)
+                  DeprecationWarning, stacklevel=2)
     app = config.get_app()
     return app.get_people_handler(**kwargs)
