@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,19 +24,18 @@
 Poser Handler
 """
 
-from __future__ import unicode_literals, absolute_import
-
+import importlib
 import os
 import sys
 import subprocess
 import logging
+from collections import OrderedDict
 
-import six
 from mako.lookup import TemplateLookup
 
 from rattail.app import GenericHandler
 from rattail.files import resource_path
-from rattail.util import import_module_path, import_reload, OrderedDict, simple_error
+from rattail.util import simple_error
 from rattail.reporting import ExcelReport
 from rattail.config import ConfigExtension
 
@@ -214,7 +213,7 @@ class PoserHandler(GenericHandler):
             from poser import reports
         except:
             if ignore_errors:
-                log.warning("cannot import poser reports module!")
+                log.debug("cannot import poser reports module!")
                 return []
             raise
 
@@ -249,8 +248,8 @@ class PoserHandler(GenericHandler):
         modpath = '.'.join((reports.__name__, key))
 
         try:
-            mod = import_module_path(modpath)
-            import_reload(mod)
+            mod = importlib.import_module(modpath)
+            importlib.reload(mod)
 
         except Exception as error:
             log.warning("import failed for %s", modpath, exc_info=True)
@@ -412,8 +411,8 @@ class PoserHandler(GenericHandler):
         modpath = '.'.join((views.__name__, key))
 
         try:
-            mod = import_module_path(modpath)
-            import_reload(mod)
+            mod = importlib.import_module(modpath)
+            importlib.reload(mod)
 
         except Exception as error:
             log.warning("import failed for %s", modpath, exc_info=True)
