@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,16 +24,11 @@
 Report Handlers
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 import decimal
 
-import six
+from wuttjamaican.util import load_entry_points
 
-from rattail.db import model
-from rattail.util import load_entry_points, load_object
-from rattail.mail import send_email
 from rattail.time import localtime
 
 
@@ -91,6 +86,7 @@ class ReportHandler(object):
         """
         Generate and return output for the given report and params.
         """
+        model = self.app.model
         data = report.make_data(session, params, progress=progress, **kwargs)
 
         output = model.ReportOutput()
@@ -113,9 +109,9 @@ class ReportHandler(object):
 
     def safe_params(self, **kwargs):
         params = {}
-        for key, value in six.iteritems(kwargs):
+        for key, value in kwargs.items():
             if isinstance(value, datetime.date):
-                value = six.text_type(value)
+                value = str(value)
             elif isinstance(value, decimal.Decimal):
                 value = float(value)
             params[key] = value
@@ -136,7 +132,7 @@ class ReportHandler(object):
         :param extra_data: Additional context data to be passed along to the
            email template.
         :param kwargs: Additional kwargs to be passed directly to
-           :func:`~rattail.mail.send_email()`.
+           :meth:`~rattail.app.AppHandler.send_email()`.
         """
         if 'attachments' not in kwargs:
             path = output.filepath(self.config)
@@ -156,15 +152,16 @@ class ReportHandler(object):
         if 'params' not in data:
             data['params'] = output.params
 
-        send_email(self.config, mailkey, data, fallback_key=fallback_mailkey,
-                   **kwargs)
+        self.app.send_email(mailkey, data, fallback_key=fallback_mailkey,
+                            **kwargs)
 
 
 def get_report_handler(config, **kwargs):
     """
     Create and return the configured :class:`ReportHandler` instance.
     """
+    app = config.get_app()
     spec = config.get('rattail.reports', 'handler')
     if spec:
-        return load_object(spec)(config)
+        return app.load_object(spec)(config)
     return ReportHandler(config)
