@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,10 +24,6 @@
 SIL Columns
 """
 
-from __future__ import unicode_literals, absolute_import
-
-import six
-
 from ..core import Object
 from .exceptions import SILColumnNotFound
 from ..util import load_entry_points
@@ -39,7 +35,6 @@ __all__ = ['get_column']
 supported_columns = None
 
 
-@six.python_2_unicode_compatible
 class SILColumn(Object):
     """
     Represents a column for use with SIL.
