@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,12 @@
 TrainWreck data models
 """
 
-from __future__ import unicode_literals, absolute_import
-
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
-from sqlalchemy.ext.declarative import declarative_base, declared_attr
+try:
+    from sqlalchemy.orm import declarative_base, declared_attr
+except ImportError:
+    from sqlalchemy.ext.declarative import declarative_base, declared_attr
 from sqlalchemy.ext.orderinglist import ordering_list
 
 from rattail import enum
@@ -40,7 +40,6 @@ from rattail.db.model.core import ModelBase
 Base = declarative_base(cls=ModelBase)
 
 
-@six.python_2_unicode_compatible
 class TransactionBase(object):
     """
     Represents a POS (or similar?) transaction.
@@ -197,7 +196,6 @@ class TransactionBase(object):
         return "{} {}-{}".format(system, self.terminal_id or "?", self.receipt_number or "??")
 
 
-@six.python_2_unicode_compatible
 class TransactionOrderMarkerBase(object):
     """
     Represents a "marker" to cross-reference one or more customer
@@ -266,7 +264,6 @@ class TransactionOrderMarkerBase(object):
         return "{} / {}".format(self.transaction, xref)
 
 
-@six.python_2_unicode_compatible
 class TransactionItemBase(object):
     """
     Represents a line item within a transaction.
@@ -452,7 +449,6 @@ class TransactionItemBase(object):
         return self.description
 
 
-@six.python_2_unicode_compatible
 class TransactionItemDiscountBase(object):
     """
     Represents a discount on a line item.
