@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,15 +24,13 @@
 TrainWreck -> Trainwreck data importing
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
+from collections import OrderedDict
 
 from rattail.importing.handlers import FromSQLAlchemyHandler, ToSQLAlchemyHandler
 from rattail.importing.sqlalchemy import FromSQLAlchemySameToSame
 from rattail.trainwreck.db import Session as TrainwreckSession
 from rattail.time import localtime, make_utc
-from rattail.util import OrderedDict
 from rattail.trainwreck.importing import model
 from rattail.trainwreck.importing.util import ToOrFromTrainwreck
 
