@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2024 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,8 @@
 Vendor Catalogs
 """
 
-from __future__ import unicode_literals, absolute_import
-
+import decimal
 import warnings
-from decimal import Decimal
-
-import six
 
 from rattail.exceptions import RattailError
 from rattail.util import load_entry_points
@@ -62,9 +58,13 @@ class CatalogParser(object):
         if config:
             self.config = config
             self.app = config.get_app()
-            self.model = config.get_model()
             self.enum = config.get_enum()
 
+            try:
+                self.model = self.app.model
+            except ImportError:
+                pass # sqlalchemy not installed
+
     @property
     def key(self):
         """
@@ -104,16 +104,16 @@ class CatalogParser(object):
             return None
 
         # No reason to convert integers, really.
-        if isinstance(value, six.integer_types):
+        if isinstance(value, int):
             return value
-        if isinstance(value, Decimal):
+        if isinstance(value, decimal.Decimal):
             return value
 
         if isinstance(value, float):
             value = "{{0:0.{0}f}}".format(scale).format(value)
         else:
             value = value.strip()
-        return Decimal(value)
+        return decimal.Decimal(value)
 
     def int_(self, value):
         """
@@ -123,7 +123,6 @@ class CatalogParser(object):
         return int(value)
 
 
-@six.python_2_unicode_compatible
 class CatalogParserNotFound(RattailError):
     """
     Exception raised when a vendor catalog parser is required, but cannot be
@@ -143,7 +142,7 @@ def get_catalog_parsers(): # pragma: no cover
     """
     warnings.warn("function is deprecated, please use "
                   "VendorHandler.get_all_catalog_parsers() instead",
-                  DeprecationWarning)
+                  DeprecationWarning, stacklevel=2)
     return load_entry_points('rattail.vendors.catalogs.parsers')
 
 
@@ -154,7 +153,7 @@ def get_catalog_parser(key): # pragma: no cover
     """
     warnings.warn("function is deprecated, please use "
                   "VendorHandler.get_catalog_parser() instead",
-                  DeprecationWarning)
+                  DeprecationWarning, stacklevel=2)
     parser = get_catalog_parsers().get(key)
     if parser:
         return parser()
@@ -168,7 +167,7 @@ def require_catalog_parser(key): # pragma: no cover
     """
     warnings.warn("function is deprecated, please use "
                   "VendorHandler.get_catalog_parser() instead",
-                  DeprecationWarning)
+                  DeprecationWarning, stacklevel=2)
     parser = get_catalog_parser(key)
     if not parser:
         raise CatalogParserNotFound(key)
@@ -181,6 +180,6 @@ def iter_catalog_parsers(): # pragma: no cover
     """
     warnings.warn("function is deprecated, please use "
                   "VendorHandler.get_all_catalog_parsers() instead",
-                  DeprecationWarning)
+                  DeprecationWarning, stacklevel=2)
     parsers = get_catalog_parsers()
     return parsers.values()
