@@ -1,11 +1,8 @@
 # -*- coding: utf-8; -*-
 
-from __future__ import unicode_literals, absolute_import
-
 from unittest import TestCase
 
-import six
-import sqlalchemy as sa
+import pytest
 
 from rattail import products as mod
 from rattail.config import make_config
@@ -17,6 +14,7 @@ class TestProductsHandler(TestCase):
 
     def setUp(self):
         self.config = self.make_config()
+        self.app = self.config.get_app()
         self.handler = self.make_handler()
 
     def make_config(self):
@@ -30,18 +28,18 @@ class TestProductsHandler(TestCase):
         # basic real-world example
         result = self.handler.make_gpc('074305001321')
         self.assertIsInstance(result, GPC)
-        self.assertEqual(six.text_type(result), '00074305001321')
+        self.assertEqual(str(result), '00074305001321')
 
         # and let it calculate check digit
         result = self.handler.make_gpc('7430500132', calc_check_digit='upc')
         self.assertIsInstance(result, GPC)
-        self.assertEqual(six.text_type(result), '00074305001321')
+        self.assertEqual(str(result), '00074305001321')
 
         # can also pass integer, and let it auto-calc check digit
         # (b/c data length makes it clear check digit is missing)
         result = self.handler.make_gpc(7430500132)
         self.assertIsInstance(result, GPC)
-        self.assertEqual(six.text_type(result), '00074305001321')
+        self.assertEqual(str(result), '00074305001321')
 
         # bad one should raise error
         self.assertRaises(ValueError, self.handler.make_gpc, 'BAD_VALUE')
@@ -51,7 +49,10 @@ class TestProductsHandler(TestCase):
         self.assertIsNone(result)
 
     def test_make_full_description(self):
-        model = self.config.get_model()
+        try:
+            model = self.app.model
+        except ImportError:
+            pytest.skip("test is not relevant without sqlalchemy")
 
         # basic example
         result = self.handler.make_full_description(
@@ -77,8 +78,13 @@ class TestProductsHandler(TestCase):
         self.assertEqual(result, "Bragg's Apple Cider Vinegar 32oz")
 
     def test_get_case_size(self):
+        try:
+            import sqlalchemy as sa
+        except ImportError:
+            pytest.skip("test is not relevant without sqlalchemy")
+
         engine = sa.create_engine('sqlite://')
-        model = self.config.get_model()
+        model = self.app.model
         model.Base.metadata.create_all(bind=engine)
         session = Session(bind=engine)
 
@@ -103,8 +109,12 @@ class TestProductsHandler(TestCase):
         self.assertEqual(result, 24)
 
     def test_get_url(self):
+        try:
+            model = self.app.model
+        except ImportError:
+            pytest.skip("test is not relevant without sqlalchemy")
+
         app = self.config.get_app()
-        model = self.config.get_model()
 
         # no url by default
         product = model.Product()
@@ -119,8 +129,13 @@ class TestProductsHandler(TestCase):
         self.assertEqual(result, 'http://example.com/products/{}'.format(uuid))
 
     def test_locate_product_for_alt_code(self):
+        try:
+            import sqlalchemy as sa
+        except ImportError:
+            pytest.skip("test is not relevant without sqlalchemy")
+
         engine = sa.create_engine('sqlite://')
-        model = self.config.get_model()
+        model = self.app.model
         model.Base.metadata.create_all(bind=engine)
         session = Session(bind=engine)
         app = self.config.get_app()
@@ -143,8 +158,13 @@ class TestProductsHandler(TestCase):
         self.assertIs(result, product1)
 
     def test_locate_product_for_vendor_code(self):
+        try:
+            import sqlalchemy as sa
+        except ImportError:
+            pytest.skip("test is not relevant without sqlalchemy")
+
         engine = sa.create_engine('sqlite://')
-        model = self.config.get_model()
+        model = self.app.model
         model.Base.metadata.create_all(bind=engine)
         session = Session(bind=engine)
         app = self.config.get_app()
@@ -173,8 +193,13 @@ class TestProductsHandler(TestCase):
         self.assertIs(result, product2)
 
     def test_locate_product_for_gpc(self):
+        try:
+            import sqlalchemy as sa
+        except ImportError:
+            pytest.skip("test is not relevant without sqlalchemy")
+
         engine = sa.create_engine('sqlite://')
-        model = self.config.get_model()
+        model = self.app.model
         model.Base.metadata.create_all(bind=engine)
         session = Session(bind=engine)
         app = self.config.get_app()
@@ -208,8 +233,13 @@ class TestProductsHandler(TestCase):
         self.assertIs(result, product2)
 
     def test_locate_product_for_upc(self):
+        try:
+            import sqlalchemy as sa
+        except ImportError:
+            pytest.skip("test is not relevant without sqlalchemy")
+
         engine = sa.create_engine('sqlite://')
-        model = self.config.get_model()
+        model = self.app.model
         model.Base.metadata.create_all(bind=engine)
         session = Session(bind=engine)
         app = self.config.get_app()
@@ -261,8 +291,13 @@ class TestProductsHandler(TestCase):
         self.assertIs(result, product2)
 
     def test_locate_product_for_item_id(self):
+        try:
+            import sqlalchemy as sa
+        except ImportError:
+            pytest.skip("test is not relevant without sqlalchemy")
+
         engine = sa.create_engine('sqlite://')
-        model = self.config.get_model()
+        model = self.app.model
         model.Base.metadata.create_all(bind=engine)
         session = Session(bind=engine)
         app = self.config.get_app()
@@ -283,8 +318,13 @@ class TestProductsHandler(TestCase):
         self.assertIs(result, product1)
 
     def test_locate_product_for_scancode(self):
+        try:
+            import sqlalchemy as sa
+        except ImportError:
+            pytest.skip("test is not relevant without sqlalchemy")
+
         engine = sa.create_engine('sqlite://')
-        model = self.config.get_model()
+        model = self.app.model
         model.Base.metadata.create_all(bind=engine)
         session = Session(bind=engine)
         app = self.config.get_app()
@@ -305,8 +345,13 @@ class TestProductsHandler(TestCase):
         self.assertIs(result, product1)
 
     def test_locate_product_for_key_upc(self):
+        try:
+            import sqlalchemy as sa
+        except ImportError:
+            pytest.skip("test is not relevant without sqlalchemy")
+
         engine = sa.create_engine('sqlite://')
-        model = self.config.get_model()
+        model = self.app.model
         model.Base.metadata.create_all(bind=engine)
         session = Session(bind=engine)
         app = self.config.get_app()
@@ -332,8 +377,13 @@ class TestProductsHandler(TestCase):
         self.assertIs(result, product1)
 
     def test_locate_product_for_key_item_id(self):
+        try:
+            import sqlalchemy as sa
+        except ImportError:
+            pytest.skip("test is not relevant without sqlalchemy")
+
         engine = sa.create_engine('sqlite://')
-        model = self.config.get_model()
+        model = self.app.model
         model.Base.metadata.create_all(bind=engine)
         session = Session(bind=engine)
         app = self.config.get_app()
@@ -355,8 +405,13 @@ class TestProductsHandler(TestCase):
         self.assertIs(result, product1)
 
     def test_locate_product_for_key_scancode(self):
+        try:
+            import sqlalchemy as sa
+        except ImportError:
+            pytest.skip("test is not relevant without sqlalchemy")
+
         engine = sa.create_engine('sqlite://')
-        model = self.config.get_model()
+        model = self.app.model
         model.Base.metadata.create_all(bind=engine)
         session = Session(bind=engine)
         app = self.config.get_app()
@@ -378,8 +433,13 @@ class TestProductsHandler(TestCase):
         self.assertIs(result, product1)
 
     def test_locate_product_for_entry(self):
+        try:
+            import sqlalchemy as sa
+        except ImportError:
+            pytest.skip("test is not relevant without sqlalchemy")
+
         engine = sa.create_engine('sqlite://')
-        model = self.config.get_model()
+        model = self.app.model
         model.Base.metadata.create_all(bind=engine)
         session = Session(bind=engine)
         app = self.config.get_app()
